import Article from "@/components/Article";

const ArticleAcupuntureBasics = () => {
  return (
    <Article
      title="Acupuncture Basics"
      author="Richard A. Feely, D.O., FAAO, FCA, FAAMA"
    >
      <p>
        The Chinese discovered acupuncture more than 5,000 years ago. Chinese
        science had a very different paradigm than the Western world. It
        emphasized wholistic patterns, relationships, cycles, and processes. In
        contrast, the Western paradigm emphasizes linear thinking, causality,
        and reductionist explanations.
      </p>
      <p>
        Acupuncture was first introduced to Europe by French Jesuits in the 17th
        Century. It was not widely accepted in the West because of the clash
        between Eastern and Western paradigms, for example, Western linear
        thinking couldn’t understand how a needle inserted into the hand could
        cure a toothache. The acupuncture analgesia did not fit into the
        existing physiological paradigm of the Western scientist and was thus
        dismissed.
      </p>
      <p>
        Until 1976, the evidence of acupuncture anesthesia was mainly anecdotal.
        There were few scientifically controlled experiments. Since then, the
        situation has changed dramatically. In the last few years, there have
        been thousands of scientifically controlled experiments in acupuncture.
        Today, there are at least 17 different lines of scientific evidence
        verifying acupuncture’s effect upon humans and animals.
      </p>
      <h2>Research and Theory</h2>
      <p>
        Research performed on animals and humans shows that specific acupuncture
        relieved pain while sham acupuncture (needles at acupoint regions) had
        no pain relieving effect. Several controlled clinical trials on chronic
        pain patients comparing real acupuncture to sham acupuncture have also
        shown that acupuncture really works better than a placebo. Perhaps more
        importantly, when acupuncture was compared to conventional treatment of
        chronic pain, it was found to be just as effective with fewer side
        effects.
      </p>
      <p>
        It is evident that needling simulates peripheral nerves in the muscles
        that send messages to the brain to release endorphins (morphine-like
        peptides in the brain.) These neurochemicals then cause analgesia by
        blocking the transmission of painful messages. Three main sites for
        endorphin acupuncture analgesia have been found. The pituitary gland is
        one site that has been shown to release endorphins into the blood
        stream. This hormone travels to the three parts of the brain and spinal
        cord to block the transmission of painful messages. The second site is
        the periaqueductal gray neurons in the midbrain which release endorphins
        that act as local transmitters to excite the rostral ventromedial
        medulla. The rostal ventromedial medulla in turn projects massively and
        selectively to pain transmitting neurons in the dorsal horn of the
        spinal cord and the trigeminal nucleus caudalis. Electrical stimulation
        in the periaqueductal gray and rostral ventromedial medulla produces
        behavioral analgesia and inhibitions of spinal pain transmission. This
        third site, spinal cord endorphin system, is where the spinal cord
        neurons release endorphins to block the release of neurotransmitters
        from afferent fibers carrying painful messages to the cord.
      </p>
      <p>
        In 1977, research showed that acupuncture analgesia inhibited the
        spinothalamic tract neurons from responding from painful inputs. This
        acupuncture effect was then blocked by naloxone, an endorphin receptor
        blocker. It has also been shown in mice and humans that naloxone blocked
        acupuncture anesthesia using behavioral measurements. Acupuncture
        research has progressed since the 1970s to date, to have no less than 17
        different lines of evidence convergent upon acupuncture endorphin
        mechanisms verifying and supporting acupuncture analgesia.
      </p>
      <h2>The Evidence</h2>
      <p>
        <strong>There are 17 points of evidence:</strong>
      </p>
      <ol>
        <li>Naloxone blocked acupuncture analgesia</li>
        <li>Six opiates antagonist block acupuncture analgesia</li>
        <li>Dextro-naloxone doesn’t block acupuncture analgesia</li>
        <li>Antibodies to endorphins block acupuncture analgesia</li>
        <li>Micro-injection of naloxone blocks acupuncture analgesia</li>
        <li>
          Genetic defects in opiate receptors causes less acupuncture analgesia
        </li>
        <li>Deficiency in endorphins causes less acupuncture analgesia</li>
        <li>
          Endorphins rise in cerebral spinal fluid and drop in the brain after
          acupuncture analgesia
        </li>
        <li>
          Acupuncture analgesia is enhanced by protecting from enzyme
          destruction
        </li>
        <li>Cross circulation of acupuncture analgesic effects</li>
        <li>Reduce pituitary endorphins block acupuncture analgesia</li>
        <li>A rise in mRNA for proenkephalin with acupuncture analgesia</li>
        <li>C-fos gene protein rises in endorphin areas of brain</li>
        <li>
          Acupuncture analgesia shows cross tolerance with morphine addiction
        </li>
        <li>
          Acupuncture analgesia works best for emotional pain like endorphin
        </li>
        <li>Lesions of arcuate nucleus blocks acupuncture analgesia</li>
        <li>Lesions of periaquaductal gray blocks acupuncture analgesia</li>
      </ol>
      <p>
        The considerable evidence for the three pathways shown above provides
        convincing proof that acupuncture analgesia is a known physiological
        phenomenon that can occur and be manipulated through the use of
        acupuncture needles and electrical stimulation.
      </p>
      <p>
        Testing the involvement of the pituitary, several experiments were
        carried out, both surgically removable pituitary and suppression of the
        pituitary endorphins by chemical manipulations; all of the experiments
        suppressed acupuncture analgesia in animals. Experiments to test the
        involvement of the midbrain were done since it had been shown that
        morphine pain relief was largely mediated by this system. Such
        experiments included direct lesions to the raphe by cutting the output
        fibers in the dorsal lateral tract, the spinal cord blockade of
        serotonin receptors, blockade of serotonin synthesis and direct
        micro-injection of naloxone into the mid brain; all of these experiments
        reduced acupuncture analgesia.
      </p>
      <p>
        Enhancement of serotonin synthesis increased acupuncture analgesia. An
        experiment measuring serotonin showed an increase product (serotonin)
        was released during acupuncture analgesia along with noradrenelinecture
        endorphin mechanisms verifying and supporting acupuncture analgesia.
      </p>
      <h2>Effectiveness</h2>
      <p>
        Acupuncture works in approximately 70% to 80% of humans and animals.
        Meanwhile, we know that the placebo only works 30% of the time.
        Acupuncture does not work all the time in all people for various
        reasons. Principally due to cholecystikinin (CCK). Those individuals
        with high CCK are poor responders to acupuncture analgesia. Good
        responders have less CCK. CCK blocks acupuncture tolerance, it acts in
        the periaquaductal gray. Animal experimentation have been done to show
        that poor responders may become better responders through the use of a
        CCK antagonist and that good responders can become poor responders by
        the use of cDNA, CCK gene.
      </p>
      <p>
        Acupuncture has been shown not to be physiologically addicting.
        Acupuncture is however additive and cumulative in its effects. It is
        more powerful after ten to fifteen treatments. Neurologically we know
        acupuncture works with a small mylenated fibers A delta-type III, and it
        does not work on larger fibers, C-fibers.
      </p>
      <h2>Conclusion</h2>
      <p>
        In conclusion, acupuncture has been used for over 5,000 years. It has a
        large body of empirical anecdotal evidence indicating its effectiveness.
        Now, scientific based research evidence indicates there are several
        causes and effects of acupuncture. Acupuncture has been shown to be
        effective for acute and chronic pain conditions. Acupuncture has also
        been found to be effective in the treatment of addiction and withdrawal
        from various drugs, gastrointestinal functions, environmental illnesses
        and cardiovascular illness, along with positively changing
        learning/memory, conditioning and immunology.
      </p>
      <p>
        As a result of this research, more and more physicians outside China are
        using acupuncture to treat many painful conditions. It is estimated that
        5,000 MDs in Germany, 30,000 in France and 60,000 in Japan use
        acupuncture along with drugs, nerve blocks and other approaches to treat
        patients with chronic pain. Here in the United States, over 1,000
        physicians and surgeons are actively involved in the practice of
        acupuncture. With increasing research and evidence, more and more
        physicians in the West will become acupuncture practitioners.
      </p>
    </Article>
  );
};

export default ArticleAcupuntureBasics;
