import Article from "@/components/Article";

const ArticleCranialManipulation = () => {
  return (
    <Article
      title="The Effect of Cranial Manipulation on the Traube-Hering-Mayer Oscillation as Measured by Laser-Doppler Flowmetry"
      author=""
    >
      <h2>Source</h2>
      <p>
        Alternative Therapies, Nov/Dec 2002, Vol. 8 No. 6<br />
        <a href="http://www.alternative-therapies.com/">
          http://www.alternative-therapies.com/
        </a>
      </p>
      <h2>Authors</h2>
      <p>
        Nicette Sergueff lectures throughout Europe on manual principles,
        diagnosis, and treatment, and maintains a private practice in Corbas,
        France. She is an assistant professor.
      </p>
      <p>
        <em>Kenneth E. Nelson </em>is a professor, and Thomas Glonek is a
        research professor in the Department of Osteopathic Manipulative
        Medicine, Chicago College of Osteopathic Medicine, Midwestern
        University, Downers Grove, Illinois.
      </p>
      <h2>Context</h2>
      <p>
        A correlation has been established between the Traube-Hering-Mayer
        oscillation in blood-flow velocity, measured by laser-Dopper-flowmetry,
        and the cranial rhythmic impulse.
      </p>
      <h2>Objective</h2>
      <p>
        To determine the effect of cranial manipulation on the
        Traube-Hering-Mayer oscillation.
      </p>
      <h2>Design</h2>
      <p>
        Of 23 participants, 13 received a sham treatment and 10 received cranial
        manipulation.
      </p>
      <h2>Setting</h2>
      <p>
        Osteopathic Manipulative Medicine Department, Midwestern University,
        Downers Grove, Illinois.
      </p>
      <h2>Participants</h2>
      <p>Healthy adult subjects of both sexes participated (N=23).</p>
      <h2>Intervention</h2>
      <p>
        A laser-Doppler flowmetry probe was place on the left earlobe of each
        subject to obtain a 5-min baseline blood flow velocity record. Cranial
        manipulation, consisting of equilibration of the global cranial motion
        patter and the craniocervical junction, was then applied for 10 to 20
        minutes; the sham treatment was manipulation only.
      </p>
      <h2>Main Outcome Measure</h2>
      <p>
        Immediately following the procedures, a 5-min postreatment laser-Doppler
        recording was acquired. For each cranial treatment subject, the 4 major
        components of the blood-flow velocity record, the thermal (Mayer)
        signal, the baro (Traube-Hering) signal, the respiratory signal, and the
        cardiac signal, were analyzed, and the pretreatment and posttreatment
        data were compared.
      </p>
      <h2>Results</h2>
      <p>
        The 10 participants who received cranial treatment showed a thermal
        signal power decrease from 47.79 dB to 38.490 dB (P &lt; .001) and the
        baro signal increased from 47.40 dB to 51.30 dB (P &lt; .021), while the
        respiratory and cardiac signals did not change significantly (P &gt; .05
        for both).
      </p>
      <h2>Conclusion</h2>
      <p>
        Cranial manipulation affects the blood-flow velocity oscillation in its
        low-frequency Traube-Hering-Mayer components. Because these
        low-frequency oscillations are mediated through parasympathetic and
        sympathetic activity, it is concluded that cranial manipulation affects
        the autonomic nervous system.
      </p>
      <h2>Introduction</h2>
      <p>
        Cranial manipulation is a form of broadly practiced alternative, manual
        medicine. A fundamental component of cranial manipulation is the primary
        respiratory mechanism (PRM).<sup>1</sup> It is described as an
        oscillation that is palpable; the cranial rhythmic impulse (CRI)2 has an
        agreed-upon frequency of 10-14 cycles per minute (cpm).<sup>2,3</sup>{" "}
        The PRM/CRI is a subtle phenomenon that is readily palpable only by
        experienced individuals, making its very existence subject to debate.{" "}
        <sup>4,5</sup>
      </p>
      <p>
        The Traube-Hering-Mayer (THM) wave is a complex oscillation in blood
        pressure and blood-flow velocity. The Traube-Hering (TH) component of
        this oscillation has a frequency of 6 to 10 cpm. Analysis of the TH was
        first described in 1865, when Ludwig Traube reported the measurement of
        a fluctuation in pulse pressure that occurred with a particular
        frequency of respiration but persisted after respiration had been
        arrested.<sup>6</sup> Fourier-transform analysis applied to blood
        physiologic parameters shows that this fluctuation consists of 3
        principal spectral peaks: the thermal or Mayer (M) wave (1.2-5.4 cmp),
        the baro or TH wave (6.0-10.0 cpm), and the respiratory wave, which
        shifts in frequency with changes in the respiratory rate.7 Multiple
        authors have commeted on the similarity between the TH wave and the CRI.
        <sup>8-11</sup>
      </p>
      <p>
        By comparing cranial manipulation with laser-Doppler flowmetery, we have
        demonstrated that the PRM/CRI is congruous with the TH component of the
        THM oscillation in blood flow velocity.<sup>12</sup> A question,
        therefore, logically arises: can cranial manipulation affect the THM
        oscillation?
      </p>
      <h2>Method</h2>
      <p>
        Healthy adult subjects (both sexes, N=23, institutional review
        board-approved informed consent obtained) were divided randomly into
        cranial palpation (n=13) and cranial manipulation groups (n=10). A
        laser-Doppler probe (BLF 21 Perfusion Monitor, Transonic Systems, Inc.
        Ithaca, NY) was placed on the left earlobe of each subject. After the
        subject was allowed to lie quietly on the examination table for 3
        minutes of equilibration, a 5-minute baseline blood-flow velocity record
        was obtained. Cranial manipulation or manipulation, with the physician
        blinded to the flowmetry recording, was then performed for 10 to 20
        minutes. Following palpation or treatment, a 5-minute postcontact
        laser-Doppler recording was acquired. During this entire procedure, the
        subject remained on the examination table, and the laser-Doppler probe
        was not disturbed.
      </p>
      <p>
        Cranial palpation (simply counting the CRI but without intervention) and
        manipulation (therapeutic intervention) were performed while the
        subjects were supine. The individual performing the procedure was seated
        at the end of the examination table with hi or her forearms resting upon
        it. The examiner’s palms conformed to the curvature of the subject’s
        head, contacting the lateral aspect of the great wings of the sphenoid
        bone and the temporal, occipital and parietal bones bilaterally. For
        this study, similar contact pressure, firm, but light enough not to
        ablate the sensation of the CRI, was employed for both palpation and
        manipulation. Manipulation was directed at modulation of the rate,
        rhythm, and amplitude of the CRI and perceived functional asymmetry
        through equilibration of the craniocervical junction and global
        anerioposterior cranial motion. Specific interventions were dictated by
        the physical findings of the individual’s cranial pattern.
      </p>
      <h2>Results</h2>
      <p>
        For each subject, 4 component parts of the blood flow velocity record
        were analyzed: the thermal (M) signal, the baro (TH) signal and the
        respiratory signal of the THM, and the cardiac signal. The mean
        precontact and postcontact data for each group were compared using the
        paired-samples 2 tailed t statistic (see Table). After palpation only,
        the thermal signal power decreased 3 dB (42.93 to 39.58 Db, P &lt;
        .054), while the baro (39.83 to 40.10 dB, P &lt; .805), respiratory
        (27.54 to 27.20 dB, P &lt; .715) and cardiac (37.92 to 37.14 dB, P &lt;
        .511) signals did not change.
      </p>
      <p>
        After cranial manipulation, the thermal signal power decreased 9 dB
        (47.40 to 51.30 dB, P &lt; .021), while the respiratory (29.72 to 30.02
        dB, P &lt; .747) and cardiac (41.11 to 40.70 dB, P &lt; .788) signals
        did not change.
      </p>
      <p>
        The 2 examples illustrated (see Figure), though visually exceptional,
        illustrate the effects that can be obtained to varying degrees with any
        subjecd, provided the treating physician possesses the requisite skill.
      </p>
      <h2>Comments</h2>
      <p>
        From the above data, we have drawn 3 conclusions. First, cranial
        manipulation has an effect on low-frequency oscillations observed in
        blood-flow velocity. It decreases the amplitude of the M wave and
        increases the amplitude of the TH wave. Second, we conclude that cranial
        manipulation affects the autonomic nervous system because it has been
        demonstrated that the M an TH waves are mediated through parasympathetic
        and sympathetic activity.7 Third, because palpation alone did not
        greatly affect blood-flow velocity oscillations, we conclude that there
        is a quantifiable difference between palpation and cranial treatment.
        This conclusion suggests that palpation alone may be used as a sham
        treatment in future research in the field of cranial manipulation.
      </p>
      <table>
        <tbody>
          <tr>
            <td colSpan={8}>
              <strong>
                Traube-Hering-Mayer signal power comparison before and after
                palpation only and cranial manipulation
              </strong>
            </td>
          </tr>
          <tr>
            <td colSpan={2}></td>
            <td colSpan={3}>
              <strong>Palpation only n=13</strong>
            </td>
            <td colSpan={3}>
              <strong>Cranial manipulation n=10</strong>
            </td>
          </tr>
          <tr>
            <td>
              <strong>Signal</strong>
            </td>
            <td>
              <strong>Doppler record segment</strong>
            </td>
            <td>
              <strong>
                Mean signal
                <br />
                power (dB)
              </strong>
            </td>
            <td>
              <strong>
                Paired difference
                <br />
                before-after +/- SD
              </strong>
            </td>
            <td>
              <em>P</em>
            </td>
            <td>
              <strong>
                Mean signal
                <br />
                power (dB)
              </strong>
            </td>
            <td>
              <strong>
                Paired difference
                <br />
                before-after +/- SD
              </strong>
            </td>
            <td>
              <em>P</em>
            </td>
          </tr>
          <tr>
            <td valign="top">
              <strong>Thermal (M)</strong>
            </td>
            <td>
              <strong>Before After</strong>
            </td>
            <td valign="top">
              42.93
              <br />
              39.58
            </td>
            <td valign="top">3.36+/-5.69</td>
            <td valign="top">.054</td>
            <td valign="top">
              47.79
              <br />
              38.49
            </td>
            <td valign="top">9.30+/-5.65</td>
            <td valign="top">.001</td>
          </tr>
          <tr>
            <td valign="top">
              <strong>Baro (TH)</strong>
            </td>
            <td>
              <strong>Before After</strong>
            </td>
            <td valign="top">
              39.83
              <br />
              40.10
            </td>
            <td valign="top">-.27 +/-3.85</td>
            <td>.805</td>
            <td valign="top">
              47.40
              <br />
              51.30
            </td>
            <td valign="top">-3.90+/-4.40</td>
            <td valign="top">.021</td>
          </tr>
          <tr>
            <td valign="top">
              <strong>Resp.</strong>
            </td>
            <td>
              <strong>Before After</strong>
            </td>
            <td valign="top">
              27.54
              <br />
              27.20
            </td>
            <td valign="top">.34+/-3.23</td>
            <td valign="top">.715</td>
            <td valign="top">
              29.72
              <br />
              30.02
            </td>
            <td valign="top">-.30+/-2.89</td>
            <td valign="top">.747</td>
          </tr>
          <tr>
            <td valign="top">
              <strong>Cardiac</strong>
            </td>
            <td>
              <strong>Before After</strong>
            </td>
            <td valign="top">
              37.92
              <br />
              37.14
            </td>
            <td valign="top">.78+/-4.15</td>
            <td valign="top">.511</td>
            <td valign="top">
              41.11
              <br />
              40.70
            </td>
            <td valign="top">.41+/-4.67</td>
            <td valign="top">.788</td>
          </tr>
        </tbody>
      </table>
      <h2>References</h2>
      <p>
        1. Sutherland WG. The Cranial Bowl. Indianapolis, Ind: American Academy
        of Osteopathy, 1986. (Original work published 1939).
      </p>
      <p>
        2. Woods JM. Woods RH. A physical finding relating to psychiatric
        disorders. J Am Osteopath Assoc. 1961;60:988-993.
      </p>
      <p>
        3. Lay E. Cranial Feild. In: Ward RC, ed. Foundations for Osteopathic
        Medicine. Baltimore, MD: Williams and Wilkins; 1997:901-913
      </p>
      <p>
        4. Ferre JC. Barbin JY. The osteopathic cranical concept: fact or
        fiction? Surg Radial Anat, 1991:13-65-179
      </p>
      <p>5. Norton JM. Dig on [Letter to the editor]. AAOJ. 2000;10(2):16:17</p>
      <p>
        6. Traube L. Uber periodische Thatigkeits-Aeusserungen des
        vasomotorishen un Hemmungs-Nervenzentrums. Centralblatt fur die
        medicinischen Wissenschaften 1865:56:881-885
      </p>
      <p>
        7. Akselrod S. Gordon D. Madwed JB, Snidman NC, Shannon DC, Cohen RJ.
        Hemodynamic regulation: investigation by spectral analysis. Am J
        Physiol. 1985:249-H867-H875
      </p>
      <p>
        8. Frymann VA. A study of the rhythmic motions of the living cranium. J
        Am Ossteopath Assoc. 1971:70-928-945
      </p>
      <p>
        9. Upledger JE. Vredevoogd JD. Craniosacral Therapy. Chicago, IL:
        Eastland Press; 1983.
      </p>
      <p>
        10. Geiger AJ. Letter to the editor. J Am Osteopath Assoc.
        1992:92-1088-1093
      </p>
      <p>
        11. McPartland JM, Mein EA. Entrainment and the cranial rhythmic
        impulse. Altern Ther Health Med. 1997:3(1):40-45
      </p>
      <p>
        12. Nelson KE, Sergueef N, Lipinski CL, Chapman A, Glonek T. The cranial
        rhythmic impulse related to the Traube-Hering-Mayer oscillation:
        comparing laser-Doppler flowmetry and palpation. J Am Osteopath Assoc.
        2001:101(3):163-173
      </p>
    </Article>
  );
};

export default ArticleCranialManipulation;
