import Article from "@/components/Article";

const ArticleCranialOsteopathyFaq = () => {
  return (
    <Article
      title="Cranial Osteopathy FAQs"
      author="Richard A. Feely, D.O., FAAO, FCA, FAAMA"
    >
      <p>
        <strong>Q. What is cranial osteopathy?</strong>
      </p>
      <p>
        A. Cranial osteopathy is a sub-specialty of osteopathic manipulative
        medicine performed by a physician. This sub-specialty deals with subtle
        motions of the body through the cranial sacral mechanism. It is a gentle
        and powerful system, part of osteopathic medicine, that uses the
        patient’s own inherent forces to overcome membranous, articular,
        ligamentous strains in the body. It is a diagnostic and treatment method
        for soft tissue injuries and especially cranial and sacral structures.
      </p>

      <p>
        <strong>Q. What is the cranial rhythm?</strong>
      </p>
      <p>
        A. It is a cyclic expansion and contraction of the membranous tissues of
        the body that occur 8 to 14 times per minute. It is distinct from other
        known pulses of the body, i.e., the heart and respiratory. It can be
        felt at all parts of the body by a skilled cranial osteopath.
      </p>

      <p>
        <strong>Q. Who performs cranial osteopathy?</strong>
      </p>
      <p>
        A. Cranial osteopathy is an osteopathic technique devised by William
        Garner Sutherland, D.O., originating in 1899 and popularized in the
        1940s to this day. It is a technique performed by osteopathic
        physicians.
      </p>

      <p>
        <strong>Q. What is cranial sacral therapy?</strong>
      </p>
      <p>
        A. Cranial sacral therapy is the use of manual techniques performed by
        therapists to unwind membranous articular strains of the cranial sacral
        mechanism. Originally developed by William Garner Sutherland, D.O.,
        popularized by John Upledger, D.O., and may be performed by any
        therapist trained in this manner.
      </p>

      <p>
        <strong>Q. Who would benefit from cranial osteopathy?</strong>
      </p>
      <p>
        A. Many patients with a variety of conditions would benefit from cranial
        osteopathy, primarily persons with soft tissue injuries with membranous
        articular strains to the head, torso and extremities. It is a part of
        the osteopathic manipulative medicine physician’s armamentarium in
        treating the whole body from a biomechanical perspective, therefore, a
        patient suffering from biomechanical dysfunction causing disease such as
        asthma, sinusitis, ear-nose-throat problems, cerebral palsy, cranial
        synestosis, plageocephalgy and muscle tension headache would benefit
        from the use of cranial osteopathy.
      </p>
      <p>
        Cranial osteopathy works on the basis of unwinding the membranous
        articular strains that are present in the body thus removing the
        biomechanical restrictions that prohibit fluid flow, improve circulation
        and restore normal homeostasis to the body part and structure.
      </p>

      <p>
        <strong>
          Q. What are the contraindications to cranial osteopathy?
        </strong>
      </p>
      <p>
        A. Patients with no biomechanical problems and patients with an aversion
        to being treated or touched.
      </p>

      <p>
        <strong>Q. How does it feel while being treated?</strong>
      </p>
      <p>
        A. The physician places a very light touch on your head, spine and
        sacrum examining the cranial rhythmic impulse and verifying the areas of
        the body where the impulse is restricted. The physician gently unwinds
        the membranous articular strains with his/her hands. When that happens,
        the patient may feel a slight sensation where the physician’s hands are
        placed, otherwise, there is no sensation of pain or any other activities
        while he/she is performing these maneuvers on your body.
      </p>

      <p>
        <strong>Q. What is cranial manipulation?</strong>
      </p>
      <p>
        A. Cranial manipulation is the application of an osteopathic physician’s
        hands to the body, palpating the cranial rhythmic impulse—also known as
        the primary respiratory mechanism, or third pulse of the body. The
        physician determines the rate and amplitude of the cranial rhythmic
        impulse, or lack thereof. Then, subtle pressure is applied to the body
        part to enhance the movement of fluid and energy to that area. After the
        connective tissue and the fascia (a web-like covering over all muscle
        and tissue) are released from tension, the cranial rhythmic impulse will
        have free rein and health will be restored to that body part.
      </p>

      <p>
        <strong>Q. How does cranial manipulation work?</strong>
      </p>
      <p>
        A. The body produces cerebrospinal fluid, which fluctuates 10 to 14
        times a minute within the dura mater—the covering of the brain and
        spinal cord. The billions of brain cells expand and contract, which
        electrically and biochemically and hemodynamically cause a perceived
        pulse—the cranial rhythmic impulse.
      </p>
      <p>
        Because of the articular design of the 22 bones of the skull, motion is
        permitted. The articular design of the sacrum (at the base of the spine)
        between the ilea or hip bones permits motion down the spine. Because the
        membranes covering the brain and spinal cord have elastin tissue and are
        allowed to expand and relax, the cranial rhythmic impulse can be felt.
        The amount of movement can be measured in millimeters and can be felt in
        all parts of the body by a skilled cranial osteopath.
      </p>

      <p>
        <strong>
          Q. What can I expect to feel during and after a treatment?
        </strong>
      </p>
      <p>
        A. During a treatment, you can expect to feel subtle pressures on the
        head, spinal column and tailbone. You may also feel a slight pounding of
        fluid under the doctor’s hand. After a treatment, you may expect to feel
        overall general well-being, as well as relief of some or all pain.
      </p>

      <p>
        <strong>
          Q. Do some patients feel cranial manipulation more strongly than
          others?
        </strong>
      </p>
      <p>
        A. Yes. Generally speaking, the more out of balance a patient is, the
        more he or she will feel the cranial manipulation. Some people are also
        more sensitive than others.
      </p>

      <p>
        <strong>Q. How long are the treatments?</strong>
      </p>
      <p>A. Cranial manipulative treatments typically take 10 to 30 minutes.</p>

      <p>
        <strong>Q. How frequently should I get a treatment?</strong>
      </p>
      <p>
        A. Depending on your condition, treatment may be recommended once or
        twice a week on an outpatient basis. As your condition improves,
        treatments should taper to twice a month, then once a month, and finally
        to three or four times a year for preventive maintenance.
      </p>

      <p>
        <strong>Q. Are there any after-treatment restrictions?</strong>
      </p>
      <p>
        A. It is not good to do heavy exercise, consume alcohol, eat a heavy
        meal or engage in sexual activity within 12 hours after a treatment.
      </p>

      <p>
        <strong>
          Q. What is the duration of the relief? Can it be permanent?
        </strong>
      </p>
      <p>
        A. The duration of relief can be from hours to days, and generally
        increases with successive treatments. Pain relief can be permanent.
      </p>

      <p>
        <strong>Q. What should I bring with me to my first appointment?</strong>
      </p>
      <p>
        A. You should bring any x-rays, MRIs, MRAs, CT scans and PET scans with
        you on your first cranial manipulation visit. Also remember to bring any
        laboratory and neurodiagnostic studies, such as EEGs, EMGs and
        NCV-SSEPs.
      </p>

      <p>
        <strong>
          Q. What age range benefits most from cranial manipulation?
        </strong>
      </p>
      <p>
        A. The younger the patient, the more benefits he or she receives from
        cranial manipulation. The best results are found in patients in the
        first six months of life, followed by age six months to two years, age
        two to six, and age seven to 18. With each successive decade, a patient
        will usually need longer and more frequent treatments to achieve the
        desired results.
      </p>

      <p>
        <strong>
          Q. Which illnesses respond best to cranial manipulation?
        </strong>
      </p>
      <p>
        A. Cranial manipulation is very effective in treating any mechanical
        trauma to the head or tailbone. Birth trauma responds the quickest and
        most completely to this form of treatment.
      </p>

      <p>
        <strong>
          Q. What is Dr. Feely’s success rate with cranial manipulation?
        </strong>
      </p>
      <p>
        A. Most patients are greatly improved or cured within six to eight
        visits.
      </p>

      <p>
        <strong>
          Q. Is there a clearinghouse for osteopaths who practice cranial
          manipulation?
        </strong>
      </p>
      <p>
        A. Yes. The Cranial Academy can give you a list of competency-tested
        cranial osteopaths in your area. For physician referrals, send a
        self-addressed, stamped business-size envelope ($0.55 postage) to:
      </p>
      <p>
        The Cranial Academy
        <br />
        Referrals
        <br />
        8202 Clearvista Parkway, #9-D
        <br />
        Indianapolis, IN 46256
      </p>
      <p>
        Please include the city and state for which you are requesting
        referrals.
      </p>
      <p>
        The Cranial Academy will also fulfill requests for physician referrals
        by e-mail or fax for a $10 charge; Visa and MasterCard are accepted.
        Requests are fulfilled within 24 hours.
      </p>
      <p>
        To request a referral by e-mail, contact:{" "}
        <a href="mailto:cranacad@aol.com">cranacad@aol.com</a>
        <br />
        Fax referral requests to: 317/594-9299
      </p>

      <p>
        <strong>Q. Can any osteopath perform cranial manipulation?</strong>
      </p>
      <p>
        A. Yes. Any licensed osteopath is able to perform manipulation,
        including cranial osteopathic manipulation. But all osteopaths are not
        highly skilled in this specialized form of treatment. Contact the
        Cranial Academy at the address above for a referral to an osteopath who
        is skilled in cranial manipulation.
      </p>

      <p>
        <strong>Q. Are there specialists within osteopathic medicine?</strong>
      </p>
      <p>
        A. Yes, there are osteopathic specialists in all recognized medical
        specialties, from obstetrics, neurosurgery and cardiology to family
        practice. Most DOs are family practitioners. A few, like Dr. Feely,
        specialize in osteopathic manipulation.
      </p>

      <p>
        <strong>
          Q. Can there be a change in the body’s reaction to prescription drugs
          while undergoing this treatment?
        </strong>
      </p>
      <p>
        A. Yes. When a person is under the influence of a narcotic, cranial
        osteopathic manipulation often takes longer, more frequent treatments.
      </p>

      <p>
        <strong>
          Q. Does Dr. Feely work in conjunction with MDs to balance a patient’s
          prescription drugs and overall treatment?
        </strong>
      </p>
      <p>
        A. Yes. Dr. Feely recognizes the importance of all of your health care
        providers understanding your treatment regimen, as well as being aware
        of any and all prescription medications you may be taking. If you need
        additional medication or changes in your medication, Dr. Feely will be
        happy to speak with your physician or prescribe it himself.
      </p>

      <p>
        <strong>
          Q. Is it realistic to expect to be prescription drug-free after
          successful treatment?
        </strong>
      </p>
      <p>
        A. Not all patients will have total relief with osteopathic
        manipulation. Some patients may need to continue a few prescription
        drugs. However, most patients will decrease their amount of medicine
        dependency, as well as the need for painkillers and other frequently
        used drugs such as migraine medications.
      </p>

      <p>
        <strong>
          Q. What is the price range for cranial osteopathic manipulation
          treatments?
        </strong>
      </p>
      <p>
        A. Dr. Feely normally performs cranial osteopathic manipulation in
        conjunction with total body osteopathic manipulation treatments. For
        price information, please contact our office manager, Farida Charania,
        at 312-266-8565.
      </p>

      <p>
        <strong>
          Q. Is a referral from an MD necessary for cranial osteopathic
          manipulation?
        </strong>
      </p>
      <p>A. No.</p>

      <p>
        <strong>
          Q. Does medical insurance cover osteopathic manipulation?
        </strong>
      </p>
      <p>
        A. Yes, most medical insurance covers osteopathic manipulative treatment
        when the claim form is properly coded and the insurance company applies
        the proper definition to those codes, and does not self-impose any
        restrictions on manipulation. Some insurance plans allow only about
        $1,000 of treatment per calendar year; other plans do not pay for an
        office visit and osteopathic manipulation performed on the same day.
      </p>
    </Article>
  );
};

export default ArticleCranialOsteopathyFaq;
