import Article from "@/components/Article";

const ArticleEarAcupunctureFaq = () => {
  return (
    <Article
      title="Ear Acupuncture FAQ"
      author="Richard A. Feely, D.O., FAAO, FCA, FAAMA"
    >
      <p>
        <strong>Q. What is ear acupuncture?</strong>
      </p>

      <p>
        A. Ear acupuncture is needle stimulation to the auricle, or external
        ear, using fine acupuncture needles.
      </p>

      <p>
        <strong>Q. What is auriculotherapy?</strong>
      </p>

      <p>
        A. Auricular therapy is needle-less stimulation of the auricle, or
        external ear, using electrical probe for alleviating pain, dysfunction
        and disease as manifest in other parts of the body.
      </p>

      <p>
        Auricular therapy uses electricity to diagnose auricular acupoints. It
        uses electricity, laser or colored filters to treat auricular acupoints.
        It is performed by a physician, acupuncturist or therapist.
      </p>

      <p>
        Auricular therapy is the bioenergetic and biomechanical approach to
        wholistic health care and pain management. It is a form of needle-less
        acupuncture. It is a diagnostic method and a therapeutic treatment of
        the microsystem. It is rooted in acupuncture teachings and research and
        it is the easiest and most “western” approach to acupuncture.
      </p>

      <p>
        <strong>Q. How does auriculotherapy work?</strong>
      </p>

      <p>
        A. Auriculotherapy works by stimulating the central nervous system
        through the cranial nerves/spinal nerves on the auricle of the ear. This
        stimulation results in neurotransmitters being stimulated within the
        periactal ductal gray and pituitary and spinal cord of the central
        nervous system. This stimulation of neurotransmitters modulates the pain
        and modulates nerve function beginning the healing process within the
        body to that organ or body part.
      </p>

      <p>
        <strong>Q. Does auriculotherapy hurt?</strong>
      </p>

      <p>
        A. Using acupuncture needles on the ear, pain may last one to three
        seconds with the placing of the needle. Otherwise, acupuncture needles
        should not hurt on the ear. If electrical stimulation is used or lasers
        are used on the ears, there should be little to no pain at all perceived
        by the patient.
      </p>

      <p>
        <strong>Q. What problems is auriculotherapy good for?</strong>
      </p>

      <p>
        A. Auriculotherapy is good for acute painful problems alleviating pain
        almost immediately or within 24 to 48 hours. Auricle therapy is good for
        chronic degenerative conditions such as osteoarthritis, rheumatoid
        arthritis and other chronic painful conditions like spinal stenosis and
        other chronic central nervous system conditions such as multiple
        sclerosis. Other conditions include diseases and dysfunctions of the
        gastrointestinal, genital urinary and cardiovascular systems. Auricular
        therapy should not take the place of acute orthodox medical care in life
        threatening situations.
      </p>

      <p>
        <strong>Q. How frequently should I be treated?</strong>
      </p>

      <p>
        A. In most cases, treatment for most chronic conditions may be treated
        once or twice per weeks. However, in some acute conditions and very
        serious conditions auriculotherapy may be applied daily for
        approximately one week to 10 days.
      </p>

      <p>
        <strong>Q. How does one perform auriculotherapy?</strong>
      </p>

      <p>
        A. It is performed by a therapist using electrical means to diagnose
        auricular acupoints. There are over 200 auricular acupoints on each ear
        that represent all parts of the body and many functional areas of the
        human organism. These points represent anatopical and neurological and
        physiological functions.
      </p>

      <p>
        The physician therapist uses a hand held wand and a diagnostic probe
        similar to a pen that measures differences in skin conductivity between
        the hand and the acupoint on the ear. The positive and negative polarity
        of that relationship and if it is extremely negative or extremely
        positive, with the touch of a button, the instrument stimulates the ear
        with electrical stimulation either positively or negatively as needed.
        With this, the physician auricular therapist will be able to diagnose
        pain, dysfunction and disease whether it be somatic, visceral or
        psychological in origin. These diagnostic aids, through research
        performed at UCLA, prove to be quite accurate for a simple test — one
        study yielding over 75% accuracy in a double-blind study.
      </p>

      <p>
        People who do not want ear acupuncture or auricular therapy should,
        obviously, not have it, but it would be wise for anyone with the
        following conditions to abstain from ear acupuncture or auricular
        therapy. These conditions include:
      </p>

      <ol>
        <li>First trimester pregnancy</li>
        <li>First two months of constitutional homeopathic treatment</li>
        <li>Patients with pacemaker or spinal cord stimulator</li>
        <li>Neonates children less than one day old</li>
        <li>Patients with no external ear</li>
        <li>
          Individuals with a known genetic abnormalities of CCK enzyme produced
          in the central nervous system. (This enzyme, which is produced in the
          brain, neutralizes the neuroprotiens that are released with
          acupuncture. Only a very small percentage of the population is
          affected. As of today, there is no simple test to identify these
          patients other than a trial of acupuncture or auricular therapy.
        </li>
      </ol>

      <p>
        <strong>Q. Are there side effects?</strong>
      </p>

      <p>
        A. The primary side effect of ear acupuncture or auricular therapy is
        tenderness or inflammation to the ear itself. Auricular therapy and
        acupuncture generally have almost no side effects, especially if one is
        using auricular therapy with electrical stimulation. If the therapist is
        using the Elector-Therapy Association’s guidelines for treatment, there
        are virtually no negative side effects.
      </p>

      <p>
        Infection is possible when the skin is pierced with the acupuncture
        needle, but is almost never heard of in auricular therapy. If the
        patient is afraid of needles, auricular therapy, rather than ear
        acupuncture should be performed.
      </p>

      <p>
        <strong>Q. What does research show about auricular acupuncture?</strong>
      </p>

      <p>
        A. In the 1980s, Drs. Oleson, Kroening, and Bresler, UCLA, in a paper
        entitled, “An experimental evaluation of auricular diagnosis: The
        somatotopic mapping of the musculoskeletal pain at the ear acupuncture
        points.” This study verified the somatotopic auricular map in a blinded
        experiment using electrical skin conductivity to 40 musculoskeletal pain
        subjects with a 75.2% accuracy. (Reference: PAIN, 8, 1980, PP. 217-229.)
      </p>

      <p>
        1985 UCLA Kroening and Oleson, “Rapid narcotic detoxification and
        chronic pain patients with auricular electro acupuncture and Maloxon.”
        Twelve out of 14 chronic pain subjects, or 85.7%, were completely
        withdrawn from narcotic medication within two to seven days with no side
        effects through the use of auricular electrical stimulation and
        acupuncture needling of two auricular points used. (Reference:
        International Journal of Addictions, 20 (9), PP. 1347-1360, 1985.)
      </p>

      <p>
        1993, UCLA, Drs. Simmons and Oleson, “Auricular electrical stimulation
        and dental pain thresholds.” Auricular electrical stimulation increased
        dental threshold by 19% and was partially reversed by Maloxone.
        (Reference: American Dental Society of Anesthesiology, 4:14-19, 1993.)
      </p>

      <p>
        1993, Drs. Oleson and Flocco, “Randomized control study of premenstrual
        syndromes triggered with ear, hand and foot reflexology.” Results show a
        significant decrease of 46% in premenstrual symptoms from true
        reflexology compared with placebo. (Reference: Obstetrics and
        Gynecology, 86, NO. 6, DEC 1993, PP. 906-911.) inhibitory system.{" "}
      </p>
    </Article>
  );
};

export default ArticleEarAcupunctureFaq;
