import Article from "@/components/Article";

const ArticleIntervertebralDiscHerniation = () => {
  return (
    <Article
      title="The Basics of Intervertebral Disk Herniation"
      author="Brian Leonard, D.O."
    >
      <h1>Introduction</h1>
      <p>
        There are a great number of conditions and a variety of states of
        illness that result in the symptom of “back/neck pain.” Back and neck
        pain can be related to conditions ranging from muscle strains, somatic
        dysfunction to nerve compression and anatomic anomalies.
      </p>

      <p>
        The focus of this article is to discuss herniation of intervertebral
        discs as a cause of pain. We will examine the pathophysiology and
        biomechanics of disc degeneration and herniation as well as aspects of
        the epidemiologic data. Lastly, it is important to mention the role that
        manual/manipulative medicine plays with regard to this issue. While the
        general principles of herniated discs may be applied to any level of the
        spine, we will discuss each spinal level from cervical, thoracic, to
        lumbar.
      </p>

      <h2>Anatomic Review</h2>
      <p>
        An intervertebral disc is formed of two elements: the nucleus pulposis
        and the anulus fibrosis. The anulus fibrosis is composed of sequential
        layers of fibrocartilage that envelope the nucleus pulposis. The nucleus
        pulposis itself is formed of a proteoglycan and a water/gel substance
        that is held loosely in place by a network of collagen and elastin
        fibers. Together they form the intervertebral disc and serve to
        distribute weight and force equally throughout the spine, even during
        motions such as flexion and extension1. Blood vessels course along the
        outer edge of the anulus fibrosis and thereby force the disc to obtain
        its nutrient supply via osmosis. When the discs age, they are subject to
        gradual degeneration as the water content decreases and the ability to
        absorb impact diminishes. Degeneration begins on a microscopic level
        around the age of skeletal maturation, or fifteen years of age. At this
        time, cell densities begin to diminish, resulting in microstructural
        tears and clefts (2).
      </p>

      <h2>Pathophysiology</h2>
      <p>
        The microstructural defects accumulate over time as a person ages and
        the pulposis protrudes deeper into the anulus. These defects can result
        in frank tears of the anulus. There are three main tears that have been
        distinguished, these include:
      </p>
      <ul>
        <li>circumferential tears or delaminations</li>
        <li>peripheral rim tears</li>
        <li>radial fissures</li>
      </ul>
      <p>
        The circumferential tears represent shearing forces acting on the
        interlaminar layers of the anulus fibrosis. The characteristic disc for
        this type of tear is an older disc that has an advanced amount of
        dessication and degeneration, retaining a limited ability to absorb
        these stressors (3). The second type of tear, the peripheral rim tears,
        are most frequently seen in the anterior portion of the disc and are
        associated with bony outgrowths. Histologic data suggest that the actual
        tears are a result of repeated microtrauma (4). Lastly, radial fissures
        represent a grouping of tears that typically occur in a posterior or
        posterolateral direction and are associated with degeneration of the
        nucleus pulposis. These tears have been simulated in cadavers with
        repeated cycles of sidebending and compression (5).
      </p>
      <p>
        These variations of degeneration, dessication, and microstructural
        defects seem to be common among studies reported in the current base of
        literature. These tears, however, have not been shown to have a
        correlation with the actual prolapse, or herniation, of the disc. The
        tears and disc degeneration have been shown to be correlated only with
        repetitive mechanical loading and cigarette smoking6 (as this inhibits
        the body’s regulatory healing mechanisms in a vast number of ways). The
        prolapse of the disc has been shown to correlate with heavy lifting.
        That is to say, the degeneration of discs, and not the herniation,
        appears to be a normal process of aging (1).
      </p>

      <h2>Epidemiology</h2>
      <p>
        For the discussion of rates of occurrence and particular mechanisms
        associated with disc herniation, we will begin at the cervical level and
        progress inferiorly to the thoracic and finish at the lumbar vertebrae.
      </p>
      <p>Cervical Disc Herniation</p>
      <p>
        Cervical radiculopathy, or pain in a pattern of the nerve root that is
        compressed, is estimated to occur in 85 per 100,000 people in the
        population. Most commonly affected regions include the seventh cervical
        vertebra, C7, and the sixth cervical vertebra, C6, at rates of 60% and
        25%, respectively (7). These radiculopathies in the cervical region are
        commonly present in specific demographic groups. For instance, sudden
        weight load on the neck while in either flexion or extension can be the
        culprit. Also, in the elderly population, osteophyte formation can play
        a role as previously mentioned. Sport-related injury can be more
        insidious in nature, and can be attributed repetitive extension/rotation
        while actively using postural muscles, as in swimming (7).
      </p>
      <p>Thoracic Disc Herniation</p>
      <p>
        Thoracic disc herniations appear to be less common than lumbar and
        cervical herniations for a number of reasons. While they peak at the
        third to fifth decade of life, similar to other herniations, estimates
        place thoracic disc herniations only between 0.25% to 1% of all disc
        herniations (10,11). One reason for decreased incidence, it is thought,
        is the lesser degree of mobility in the thoracic spine due to the
        presence of the rib cage. The articulation of the rib head with the
        vertebral body naturally limits the amount of flexion, extension, and
        sidebending. The majority of thoracic herniations occur below the level
        of T7. Rib pairs 8-10 maintain a cartilaginous attachment to the
        sternum, thus allowing more motion than vertebrae at higher levels. Rib
        pairs 11 and 12 are known as “floating ribs” and do not maintain any
        attachment to the sternum. This supports the theory that part of the
        pathophysiology of herniated thoracic discs is directly related to the
        ability of the segment to maintain a certain degree of flexability (12).
      </p>
      <p>Lumbar Disc Hernation</p>
      <p>
        Herniation of the nucleus pulposis of the lumbar disc is present more
        commonly than the former two types. It is estimated that 95% of
        herniated lumbar discs occur at the L4-L5 or L5-S1 level (13). Typical
        presentation includes radicular pain that patients often describe as
        shooting or stabbing pain that courses down the leg. There may also be
        paresthesias present in the same distribution pattern. Often, the pain
        is exacerbated by coughing, sneezing, straining, or standing for long
        periods of time (14), as this increases the pressure on the disc and
        therefore on the impinged nerve root. Pain is usually relieved by rest
        and taking weight off of the prolapsed disc.
      </p>

      <p>Manual/Manipulative Medicine and Cervical Disc Herniation</p>
      <p>
        Considering the implications of nerve root impingement (including pain,
        paresthesia, and decreased motor function) secondary to a herniated
        disc, there is a natural concern regarding the safety of manual
        manipulation of such an anomalous disc.
      </p>
      <p>
        With regard to manipulation, a 2006 study was done to evaluate the
        efficacy and safety of cervical manipulation in patients with spinal
        cord compression and radiculopathy. The study incorporated a variety of
        chiropractic techniques, including high-velocity, low-amplitude methods.
        The conclusions drawn by the authors states, “The finding of cervical
        spinal cord encroachment on magnetic resonance imaging, in and of
        itself, should not necessarily be considered an absolute
        contraindication to manipulation.” (8) The authors are specific in
        mentioning exclusion criteria such as acute myelopathy or changes
        indicating myelomalacia and make clear the message that special care and
        astute clinical judgement need be exercised in cases of cervical
        radiculopathy and pathologic segments.
      </p>
      <p>
        A separate study suggests othewise, stating, “Cervical spinal
        manipulation therapy may worsen preexisting cervical disc herniation or
        cause disc herniation resulting in radiculopathy, myelopathy, or
        vertebral artery compression.” (9) This study describes 22 case studies
        and states in its conclusion a list of absolute contraindications
        including patients with rheumatoid arthritis, acute fractures and
        dislocations, os odontoideum, infection of bone, osseous malignancies,
        or cervical myelopathy. These case studies included reports from
        patients previously treated by chiropractors as well as osteopathic
        physicians. The article puts forth the modality of surgical intervention
        as the best treatment for certain cases of disc herniation and
        radiculopathy.
      </p>
      <p>
        With regard to the necessity of surgical intervention, let us consider a
        2007 article from the Massachusetts Medical Society (15). The study
        examines the outcomes of two groups of patients with herniated lumbar
        discs who were randomly assigned to either a surgical intervention or
        observation and symptom management. The study was inconclusive
        statistically due to the high rate of crossover. That is, 40% of
        patients assigned to the surgical intervention declined surgery because
        their symptoms improved before any intervention could take place (with
        observation alone). Conversely, 45% of patients referred to the
        observation therapy, opted for surgical intervention due to worsening of
        symptoms (15). Even though the study is scholastically inconclusive and
        statistically insignificant, it does highlight the need for
        individualized care.
      </p>

      <h2>Conclusion</h2>
      <p>
        As with any topic at the forefront of medicine, especially issues which
        can be treated via different modalities and by different specialists,
        there will be controversy, bias, and ever-emerging new evidence to
        consider. This article demonstrates the basic science behind disc
        degeneration leading to pathologic herniation. It also shows two sides
        of a clinical debate to which there is no defined rule for treatment.
        Patients, therefore, need to be evaluated and treated appropriately on
        clinical grounds of their individual situation by a physician
        well-versed in neuromusculoskeletal medicine to determine which specific
        modality best suits the individual.
      </p>
      <h2>References:</h2>
      <ol>
        <li>
          Michael A. Adams, PhD; Peter J. Roughley, PhD What is Intervertebral
          Disc Degeneration, and What Causes It? Spine. 2006;31(18):2151-2161
        </li>
        <li>
          Boos N, Weissbach S, Rohrbach H, et al. Classification of age-related
          changes in lumbar intervertebral discs: 2002 Volvo Award in basic
          science. Spine 2002;27:2631-44.
        </li>
        <li>
          Goel VK, Monroe BT, Gilbertson LG, et al. Interlaminar shear stresses
          and laminae separation in a disc. Finite element analysis of the L3-L4
          motion segment subjected to axial compressive loads. Spine
          1995;20:689-98.
        </li>
        <li>
          Hilton RC, Ball J. Vertebral rim lesions in the dorsolumbar spine. Ann
          Rheum Dis 1984;43:302-7
        </li>
        <li>
          Adams MA, Bogduk N, Burton K, et al. The Biomechanics of Back Pain.
          Edinburgh, UK: Churchill Livingstone; 2002
        </li>
        <li>
          Battie MC, Videman T, Gill K, et al. 1991 Volvo Award in clinical
          sciences. Smoking and lumbar intervertebral disc degeneration: An MRI
          study of identical twins. Spine 1991;16:1015-21
        </li>
        <li>
          Malanga, Gerard A MD Cervical Radiculopathy. Spine 2006 accessed via
          emedicine
          http://www.emedicine.com/sports/TOPIC21.HTM#section~AuthorsandEditors
        </li>
        <li>
          Murphy, DR; Hurwitz, EL; Gregory AA. Manipulation in the presence of
          cervical spinal cord compression: a case series. J Manipulative
          Physiol Ther. 2006 Mar-Apr;29(3):236-44
        </li>
        <li>
          David G. Malone, M.D., Nevan G. Baldwin, M.D., Frank J. Tomecek, M.D.,
          Christopher M. Boxell, M.D., Steven E. Gaede, M.D., Christopher G.
          Covington, M.D., Kenyon K. Kugler, M.D. Complications of Cervical
          Spine Manipulation Therapy: 5-Year Retrospective Study in a
          Single-Group Practice. Neurosurg Focus 13(6), 2002. © 2002 American
          Association of Neurological Surgeons
        </li>
        <li>
          Fisher, C., Noonan, V., Bishop, P., Boyd, M., Fairholm, D., Wing, P.,
          et al. (2004). Outcome evaluation of the operative management of
          lumbar disc herniation causing sciatica. Journal of Neurosurgery, 100,
          317â€“324.
        </li>
        <li>
          Strayer, Andrea J Lumbar Spine: Common Pathology and Intervention J
          Neurosci Nurs. 2005;37(4):181-193
        </li>
        <li>
          Thomas L. Schwenk, MD Is Surgery Necessary for Lumbar Disc Herniation?
          Journal Watch. 2007;5(11) ©2007 Massachusetts Medical Society
        </li>
      </ol>
    </Article>
  );
};

export default ArticleIntervertebralDiscHerniation;
