import Article from "@/components/Article";

const ArticleIntroToOsteopathy = () => {
  return (
    <Article
      title="Introduction to Osteopathy"
      author="Richard A. Feely, D.O., FAAO, FCA, FAAMA"
    >
      <h2>Section A | What is it?</h2>
      <p>
        Today, only one branch of mainstream medicine follows the Hippocratic
        philosophy of medical care that centers on the patient, not the disease.
        It is Osteopathic Medicine and, currently, some 36,233 osteopathic
        physicians and surgeons offer this dimension in medical care.
      </p>
      <p>
        Doctors of Osteopathic Medicine (D.O.’s) are fully licensed and
        recognized physicians and surgeons who stress the unity of all body
        systems. They emphasize holistic medicine-awareness of proper nutrition
        and environmental factors; a hands-on approach to medicine; and a unique
        aid to the diagnosis and treatment of various illnesses known as
        Osteopathic Manipulative Treatment.
      </p>
      <p>
        One of the Osteopathic concepts of good medicine is that the body’s
        musculoskeletal system is central to the patient’s well-being.
      </p>
      <p>
        The system includes the bones, muscles, tendons, tissues, nerves and
        spinal column–about 60 percent of the body mass. This framework works
        with all the body’s organs. It responds–properly or improperly—every
        time a breath is drawn or any other body movement occurs. Besides being
        prone to mechanical disorders, the musculoskeletal system reflects many
        internal illnesses and may aggravate or accelerate the disease process
        throughout the body. The osteopathic physician takes advantage of this
        fact in management not only of problems of the musculoskeletal system
        itself, but also in managing disorders affecting the rest of the body as
        well.
      </p>
      <p>
        Osteopathic physicians utilize all of the recognized procedures and
        modern technologies for prevention, diagnosis and treatment of disease,
        including drugs, radiation and surgery. In addition, the D.O. assesses
        the musculoskeletal system by the use of a finely trained sense of touch
        with the hands in a process called palpatory diagnosis. Disorders found
        there are treated by the introduction of carefully applied manual
        forces, directed to the bones, muscles and joints, in a type of
        treatment called Osteopathic Manipulative Treatment (OMT), or simply
        “manipulation.” Osteopathic manipulation of the musculoskeletal system
        is a proven technique for many diagnoses and treatments. Often, it can
        provide an alternative to therapies involving drugs or surgery.
      </p>
      <p>
        Because musculoskeletal dysfunction can mimic many diseases, osteopathic
        manipulation is an important component in diagnosis, as well as a means
        of correcting structural problems.
      </p>
      <p>
        For example, it has been well-documented that diseases of specific
        organs can produce pain in other parts of the body. Stomach ulcers
        consistently cause area of spinal pain and irritation just below the
        shoulders in the back. The radiation of pain to the loin is the
        reflection of pain and disability to the left shoulder following heart
        disease. In diagnosing such diseases, D.O.’s recognize that symptoms can
        be produced without actual disorder in organs to which pain has been
        referred.
      </p>
      <p>
        Also, disturbances affecting the musculoskeletal system can cause
        symptoms that stimulate other illnesses. Among the most common causes of
        recurrent headaches, for example, is disorder of the cervical (upper)
        portion of the spinal column. Properly applied manipulative treatment,
        particularly directed to the head and neck, can often relieve headache
        symptoms when other remedies have failed.
      </p>
      <p>
        Osteopathic Manipulative Treatment is often part of the medical
        treatment for stress headaches, sinus problems and pulmonary distress.
        Obstetricians often use manipulation to relieve low back pain during
        pregnancy or as additional medical treatment for menstrual cramps.
      </p>
      <p>
        Studies indicate that Osteopathic Manipulative Treatment, as part of the
        total patient treatment, actually accelerates the rate of recovery from
        illness or injury, keeping hospital or home stays to a minimum.
      </p>
      <p>
        By combining unique osteopathic principles with traditional diagnostic
        and therapeutic procedures, D.O.’s offer a balanced system of health
        care to both prevent and cure disease. The osteopathic approach is a
        true system of preventive medicine, treating the whole person, not just
        the disease.
      </p>

      <h2>Section B | What is the Difference?</h2>
      <p>
        American osteopathic physicians are fully licensed physicians and
        surgeons. To become fully licensed, they must graduate from one of 16
        osteopathic medical schools accredited by the Bureau of Professional
        Education of the American Osteopathic Association. After completing
        osteopathic medical school, D.O.s serve a one-year internship. During
        that year, they gain hands-on experience in internal medicine,
        obstetrics/gynecology, family practice, pediatrics and surgery. Often a
        D.O. will opt to continue their education by entering a two to six year
        residency program in a specialty area such as cardiology, neurology or
        thoracic surgery.
      </p>
      <p>
        There are currently 35,000 D.O.s in the United States, with 60 percent
        of them in primary care areas of family practice, internal medicine,
        obstetrics/gynecology and pediatrics. D.O.s comprise 5.5 percent of the
        total physician population and 18 percent of all physicians in the
        military. By the year 2000, there will be 45,000 osteopathic physicians
        in practice in the United States. Each year, 100 million patient visits
        are made to D.O.s.
      </p>
      <p>
        Unlike in England, in the USA an osteopathic doctor is a fully licensed
        and trained physician and surgeon like an MD but with the addition of
        osteopathic manipulation. Each DO is licensed by each individual state
        to practice Osteopathic Medicine and Surgery. An English DO to practice
        in the US would have to take 4 years of Osteopathic Medicine at a US
        college plus 3 years of residency/internship, then pass a national or
        state board exam. He would then be able to apply and receive a state
        license.
      </p>
      <p>DOs and MDs are Similar</p>
      <ol>
        <li>
          All must have four years of undergraduate training with an emphasis on
          science courses.
        </li>
        <li>All must complete four years of basic medical education.</li>
        <li>
          All may choose a medical specialty after completing medical school.
        </li>
        <li>
          All must pass an unlimited physician and surgeon state licensing
          examination.
        </li>
        <li>
          All may practice in fully accredited, licensed hospitals and medical
          centers.
        </li>
      </ol>
      <p>DOs and MDs are Different</p>
      <ol>
        <li>
          <strong>D.O.s focus on preventive health care.</strong>
        </li>
        <li>
          <strong>
            D.O.s receive additional training in the musculoskeletal system,
            gaining a therapeutic and diagnostic advantage.
          </strong>
        </li>
        <li>
          <strong>
            D.O.s do not treat specific illnesses or symptoms, but instead
            practice a whole person approach to medicine.
          </strong>
        </li>
        <li>
          <strong>
            D.O.s incorporate osteopathic manipulative treatment (OMT) into
            their practice which allows them to use their hands to diagnose and
            treat soft tissue injury or illness, thereby encouraging the body’s
            natural tendency toward health.
          </strong>
        </li>
      </ol>

      <h2>DOs, MDs and DCs</h2>
      <p>
        While health care practitioners are very familiar with the similarities
        and differences between their particular treatment approaches, many
        times the public is not. The following table is provided to help give a
        general overview of the training and root philosophies of these three
        professional disciplines.
      </p>
      <table>
        <tr>
          <th></th>
          <th>Osteopathic Physicians (DO)</th>
          <th>Allopathic Physicians (MD’s)</th>
          <th>Chiropractors (DC’s)</th>
        </tr>
        <tr>
          <td>
            <strong>Undergraduate Training Required</strong>
          </td>
          <td>4 years</td>
          <td>4 years</td>
          <td>4 years</td>
        </tr>
        <tr>
          <td>
            <strong>Postgraduate Training Required</strong>
          </td>
          <td>5-8 years</td>
          <td>5-8 years</td>
          <td>3-4 years</td>
        </tr>
        <tr>
          <td>
            <strong>Hospital Residency Required</strong>
          </td>
          <td>Yes</td>
          <td>Yes</td>
          <td>No</td>
        </tr>
        <tr>
          <td>
            <strong>Able to Prescribe Drugs</strong>
          </td>
          <td>Yes</td>
          <td>Yes</td>
          <td>No</td>
        </tr>
        <tr>
          <td>
            <strong>Able to Perform Surgery</strong>
          </td>
          <td>Yes</td>
          <td>Yes</td>
          <td>No</td>
        </tr>
        <tr>
          <td>
            <strong>Training in Bodily Manipulation</strong>
          </td>
          <td>
            Receives 300-500 hours extensive training in bodily manipulation
            including cranial, extremity, spinal joints, and connective tissue
          </td>
          <td>
            Receives no formal training in manipulation, spinal or otherwise
          </td>
          <td>Receive up to 600 hours in the use of spinal manipulation</td>
        </tr>
        <tr>
          <td>
            <strong>Founders</strong>
          </td>
          <td>
            A.T. Still, physician whose philosophy is a “whole person” approach
            and whose emphasis was on disease prevention as well as cure. A.T.
            Still was an American original.
          </td>
          <td>
            German trained physicians who viewed the body as being comprised
            primarily of parts and who emphasized treating symptoms through
            drugs and surgery.
          </td>
          <td>
            D. D. Palmer who felt that spinal manipulation could effectively
            address 95% of all illness. Briefly studied with A. T. Still, then
            developed his own techniques.
          </td>
        </tr>
      </table>

      <h2>Section C | Principles</h2>
      <p>
        Osteopathy is the knowledge of the structure, relations and functions of
        each part and tissue of the human body applied to the adjustment in the
        correction in whatever may be interfering with the harmonious operation.
        Doctors of osteopathy conceive of man as a biomechanism, an organic
        machine which, as long as the cells, tissues, organs, muscles, ligaments
        and bones are normal in themselves in their reciprocal relationships,
        they will function normally. They maintain that structural integrity and
        physiological adjustment of the tissues and fluid tensions of the
        organism which form the most important factors in maintaining health.
        Life essentials-food, water, light, air, heat, exercise, protection and
        rest-are necessary also environmental and psychological harmony. In an
        organism structurally perfect, these constitute the requirements of man
        for maintaining health. The principles of osteopathy follow the logic of
        an applied knowledge of anatomy, physiology and pathology.
      </p>
      <p>The principles of Osteopathy are as follow:</p>
      <ol>
        <li>that the body is a unit</li>
        <li>structure and function are reciprocally interrelated</li>
        <li>the body possesses self regulating mechanisms</li>
        <li>
          the body rationale therapy is based upon knowledge and use of the
          above three principles.
        </li>
      </ol>
      <p>
        The osteopathic concept includes surgery which osteopathic physicians
        practice and recommend as indicated. Osteopathy is not drug-less
        profession in the strict sense of the word. It uses drugs which have
        specific scientific value and proven effectiveness. The osteopathic
        physician is a skilled engineer of the vital human mechanism influencing
        by manipulation and other osteopathic measures the activity of the nerve
        cells, glands and organs and the distribution and the distribution of
        fluids and the discharge of nerve impulses therefore, normalizing tissue
        fluid and function.
      </p>
    </Article>
  );
};

export default ArticleIntroToOsteopathy;
