import Article from "@/components/Article";

const ArticleNeuralBiologicalMechanisms = () => {
  return (
    <Article
      title="Neural Biological Mechanisms"
      author="Richard A. Feely, D.O., FAAO, FCA, FAAMA"
    >
      <p>
        The goal of this article is to provide the clinician with information
        and knowledge of known biological mechanisms involved in somatic
        dysfunction.
      </p>
      <p>The reader will have the ability to describe:</p>
      <ul>
        <li>
          The neural endocrine-immune network and its relationship to somatic
          dysfunction
        </li>
        <li>How somatic dysfunction is endocrine-controlled and maintained</li>
        <li>
          Some of the known mechanisms of how somatic dysfunction is altered
          biomechanically, biochemically, and bioenergetically
        </li>
      </ul>
      <p>
        The human body is a complex interdependent relationship of structure,
        function, and mind. The body possesses complex homeostatic mechanisms
        that maintain equilibrium for self-regulation and self-healing. These
        homeostatic mechanisms represent an integrated network of messenger
        molecules produced by cells in neural, endocrine, and immune systems.
        Their signal coding and messenger molecules communicate through receptor
        complexes located on cell membranes. The critical role of the nervous
        system, especially the lymphatic, forebrain, and hypothalamus,
        influences the output of the endocrine and immune systems.
      </p>
      <h2>Traditionally, the Immune and Nervous Systems</h2>
      <p>
        Traditionally, the immune and nervous systems were considered separate
        and independent, each with its own cell types, cell functions, and
        intercellular regulators. Altered function in each system was related to
        the disease considered specific to that system. We now recognize not
        only the interdependence and interlocking molecular organization but
        also their extensive integration with the endocrine system. The
        conceptual separations between the neural endocrine immune system
        concerning structure, function, and communication have been discarded.
        In their stead is a combination of multiple dimensional network
        contributing to the functional unity of the body.
      </p>
      <p>
        Today, we recognize this multifactorial nature is a result of the
        following interactions of genetic, endocrine, nervous, immune, and
        behavioral-emotional systems. This complex bi-directional interaction
        occurs within the neural-endocrine-immune network. This network forms
        the prime defense against disease and is responsible for the resistance
        of infectious disease as well as cancer. The sensory information from
        external and internal sources is tightly integrated with cognitive and
        emotional processes which influence their neural endocrine immune
        network through the hypothalamic-pituitary-adrenal axis.
      </p>
      <h2>Messengers</h2>
      <p>
        The basis for communication in the neural-endocrine-immune system is the
        numerous messenger molecules that are released in the extracellular
        fluid. These signal codes are small peptides, glycoproteins, amines, and
        steroids. They express their activity through autocrine
        (self-stimulating), paracrine (stimulates local tissue), synaptic, and
        hormonal activity.
      </p>
      <h2>The Endocrine System</h2>
      <p>
        The endocrine system is described as using blood-borne messengers
        operating over long distances by humoral transport. The neural system is
        described as using chemical transmitters released into the neural
        synaptic cleft, separating the pre and post-synaptic specialized nerve
        cells. These common cellular mechanisms are bi-directional in
        communication. Their similar molecular structure of many of the
        messengers and the receptors are combined to transcend the traditional
        borders that separate the neural, endocrine, and immune systems over the
        years.
      </p>
      <p>
        Monitoring the concentration of many of these extracellular messengers.
        The central nervous system, particularly the limbic system and
        hypothalamus, directly modulates the activity of the autonomic nervous
        system and the endocrine systems. See The Network. Both of these systems
        have extensive communication with the immune systems, thereby regulating
        it under neural modulation as well. This combined action is
        multi-dimensional and creates a compensatory reserve that enables the
        body to mount an adaptive response to stressful conditions regardless of
        their origin whether somatic, visceral, or psychogenic.
      </p>
      <h2>Stimuli-Somatic</h2>
      <p>
        Somatic, visceral, and emotional stimuli act as drivers capable of
        influencing the activity via the hypothalamus, the spinal cord,
        pituitary, to the autonomic nervous system, endocrine system, and immune
        system, causing the general adaptive response. Noxious somatic stimuli
        initiate protective reflexes providing the central nervous system with
        warning signs. They influence the release of extracellular messengers
        from the endocrine immune access system just described.
      </p>
      <p>
        When activated by noxious stimuli such as rises from somatic
        dysfunction, small capillary primary afferent fibers called alpha-gam
        lambda and C-fibers, a-C-fibers or collectively referred to as (B
        afferent system) from peripheral nociceptor endings, release neural
        peptides such as substance P into the surrounding tissue thereby
        initiating neurogenic inflammation.
      </p>
      <p>
        The B afferent fibers systems represent a small subset of small
        capillary primary afferent fibers with high threshold for activation
        that are present in both somatic and visceral tissue. Central processes
        of these fibers stimulate cells in the dorsal horn of the spinal cord.
        Within the dorsal horn, the cells responding to the nociceptive input
        initiate signals carried to the motor nuclei of the ventral horn to
        alter the tonal muscles innervated by that particular spinal segment and
        through the anterior lateral tract of the spinal cord which communicates
        with the brain stem and the hypothalamus.
      </p>
      <p>
        A significant result of the nociceptive input is increased activity in
        the hypothalamic-pituitary-adrenal axis culminating in increased output
        of norepinephrine from the sympathetic nervous system. This reflex can
        be blocked by selectively eliminating the small capillary primary
        afferent fibers. Capsaicin reduces the level of substance P in the
        peripheral nervous system by destroying the small caliber primary
        afferent fibers. This diminishes the hypothalamic response and reduces
        the pituitary adrenal and autonomic responses to somatic stressors. The
        neural-endocrine-immune network is affected by the output of the signals
        from somatic dysfunction by initiating a compensatory shift in
        extracellular messengers that then alters the function of the immune
        system.
      </p>
      <p>
        Collins and Strauss found that modulation of the sympathetic nervous
        system plays an integral part in somatic pain and is a principal
        mechanism of acupuncture’s action. The control of somatic sympathetic
        vasomotor activity before and after the placement of acupuncture needles
        resulted in pain relief by reducing sympathetic vasomotor activity.
      </p>
      <p>
        Nakamura, et al. found that afferent pathways of diskogenic low back
        pain are transmitted mainly by sympathetic afferent fibers in the L2
        nerve root and after needle injection, pain dissipated.
      </p>
      <h2>Stimuli-Visceral</h2>
      <p>
        The visceral factors in the cervical, thoracic, abdominal, and pelvic
        areas, as well as peripheral blood vessels, communicate with the brain
        stem and spinal cord through an extensive complement of afferent fibers
        also considered part of the B afferent system. The visceral afferent
        fibers reach their target organs by coursing in the same nerves as the
        efferent autonomic fibers. They follow the routes of the vascular
        system. The visceral sensory fibers, typically small caliber and having
        little or no myelin, have cell bodies located in the thoraco-lumbar
        dorsal root ganglia and in ganglia of several cranial nerves. These
        central processes, neurons, terminate in the superficial and deep
        regions of the dorsal horn of the spinal cord.
      </p>
      <p>
        Spinal trigeminal nucleus and solitary nucleus of the vagus. The
        thoraco-abdominal and pelvic organs have extensive sensory innervations.
        These afferent fibers travel to the central nervous system with efferent
        autonomic fibers. These sensory fibers traveling in the parasympathetic
        nerves such as the vagus carry non-noxious information for reflex
        control of the organ. Those traveling with the sympathetic nerves such
        as the greater splanchnic carry noxious information packets.
      </p>
      <p>
        The neurons of the deeper portions of the dorsal horn receive extensive
        convergence of information from the small caliber sensory axons arising
        in both visceral and somatic sources.
      </p>
      <p>
        A similar convergence of somatic and visceral input is seen in the
        solitary nucleus of the vagus. Neurons responsive to both visceral and
        somatic nociceptive stimuli are located in the spinal cord, brain stem,
        hypothalamus, and thalamus. These dual response neurons provide an
        explanation for the phenomenon of referred pain between visceral and
        somatic sources.
      </p>
      <h2>Stimuli-Emotional</h2>
      <p>
        The emotional factors of the human effecting the neural endocrine immune
        network arise largely from the limbic forebrain system and hypothalamus.
        The major components of the limbic forebrain include large portions of
        associated neocortex, which include the prefrontal area, the cingulate
        cortex, the insular cortex, and the inferior medial aspect of the
        temporal lobe. Hippocampal formation and the amygdala receive extensive
        connections from the frontal parietal and cingulate associational areas
        of the neocortex and in turn project to the hypothalamus from the fornix
        and striaterminalis, influencing the hypophyseotropic and hypothalamic
        nuclei.
      </p>
      <p>
        This limbic forebrain areas exert considerable influence over the
        pituitary gland as well as the autonomic nervous system affecting growth
        hormone, ACTH, prolactin, and somatostatin. The limbic system also
        increases the sympathetic output from the spinal cord. These alterations
        in the neural-endocrine activity affect the metabolic processes of the
        body, shifting peripheral tissue to a catabolic form of metabolism,
        leading to marked changes in the function of the immune system,
        including stress-induced suppression of immune function. These
        conditions characterize the general adaptive response in life.
      </p>
      <p>
        Highly stressful circumstances in life significantly alter the status of
        the immune system. This can include the death of a loved one, caring for
        a family member with chronic progressive disease, summer vacation,
        change in lifestyle, divorce, new job, etc.
      </p>
      <p>
        The regulation of the neural-endocrine-immune network increases
        susceptibility to various disease states. Overproduction or
        underproduction of extracellular messages in response to either external
        or internal stimuli or as a secondary response to other
        disease-dysfunctional processes result in dysfunction of many aspects of
        the network. The aging process also alters the regulation of the network
        and is associated with various disease-dysfunctional states.
      </p>
      <p>
        Lundberg showed that psychosocial factors significantly associated with
        back pain and shoulder problems were related to psychophysiological
        stress levels, i.e., high psychophysiological stress levels and low work
        satisfaction.
      </p>
      <p>
        He also found that mental and physical stress was found to increase
        physiological stress levels and muscular tension and that mental stress
        is of importance for the development of musculoskeletal symptoms and
        pain. In addition, mental stress is not only induced by high demands but
        also by demands that are too low which happens in many repetitive and
        monotonous work situations. Interestingly enough, women are more prone
        than men to have somatic complaints with repetition and monotonous work.
      </p>
      <h2>The Network</h2>
      <p>
        <strong>SELECTED NEURAL REGULATORS</strong>
      </p>
      <ul>
        <li>Catecholamines: Dopamine, Norepinephrine</li>
        <li>Cholines: Acetylcholine</li>
        <li>Indolamines: Serotonin</li>
        <li>
          Peptides: Substance P, Neuropeptide Y, Calcitonin gene-related,
          Polypeptide, Enkaphalins, Endorphins, Neurotensin, Cholecystokinin,
          Angiotensin II, Vasoactive intestinal polypeptide, Bombesin,
          Adrenocorticotropin, Somatostatin, Corticotropin
        </li>
        <li>Amino Acids: Glutamate, Aspartate, GABA, Glycine</li>
        <li>Dynorphin, Histamine</li>
        <li>Purines: Adenosine</li>
      </ul>
      <h2>CELL TYPES OF THE IMMUNE SYSTEM</h2>
      <ul>
        <li>Thymocytes: Lymphoid Cells of the thymus</li>
        <li>
          T-Cells: Lymphoid cells that mature in the thymus & express the T-cell
          receptor (TCR)
        </li>
        <li>
          Helper T-Cells: Lymphoid cells responding to cell surface antigens by
          secreting cytokines
        </li>
        <li>
          Cytotoxic T-Cells: Lymphoid cells responding to the cell surface
          antigens by lysing cell producing the antigen
        </li>
        <li>
          B-Cells: Lymphoid cells that, when activated, are capable of producing
          immunoglobulins
        </li>
        <li>
          Natural Killer Cells: Lymphoid cells capable of killing tumor cells
          and virus/infected cells
        </li>
        <li>
          Neutrophils: Major Lymphoid cell of the acute inflammatory response
          and effector cells of humoral immunity
        </li>
        <li>
          Basophils: Effector cells of IgE-mediated immunity that secrete
          histamine granules in response to IgE activation
        </li>
        <li>
          Eosinophils: Lymphoid cells containing lysosomal granules that can
          destroy parasites
        </li>
      </ul>
      <h2>NON-LYMPHOID CELL TYPES</h2>
      <ul>
        <li>
          Fibroblast: Connective tissue cell capable of secreting and
          maintaining the collagenous fiber matrix
        </li>
        <li>
          Endothelial Cell: Squamous cell lining of the inner aspect of the
          vascular system
        </li>
        <li>
          Mesangial Cells: Specialized mesenchymal cells found in the renal
          glomerulus
        </li>
        <li>
          Chromaffin Cell: Neural peptides secreting cell found in the adrenal
          medulla
        </li>
        <li>
          Enterochromaffin Cell: Neural peptides secreting cell found in the
          lining of the gastrointestinal system
        </li>
        <li>
          Hepatocyte Liver Cell: Liver cell capable of secreting the acute phase
          proteins
        </li>
        <li>
          Endometrial Cell: Epithelial cell lining the inner surface of the
          uterus
        </li>
        <li>
          Astrocyte: Neuroglial cell found in the central nervous system
          involved in forming the blood-brain barrier
        </li>
        <li>
          Oligodendrocyte: Neuroglial cell forming myelin sheath around axons in
          the central nervous system
        </li>
        <li>
          Osteoblast: Specialized mesenchymal cells capable of secreting the
          osteomatrix for the formation of bones
        </li>
        <li>
          Osteophyte: Connective tissue cell found in bone representing a mature
          form of osteoblast
        </li>
        <li>
          Reticular Cell: Endodermal cell creating a three-dimensional network
          for lymphocytes in the thymus, spleen, and lymph nodes
        </li>
      </ul>
      <h2>IMMUNOREGULATORS</h2>
      <ul>
        <li>Interleukins 1-7</li>
        <li>Interferons alpha, beta, and gamma</li>
        <li>Tumor necrosis factor, beta</li>
        <li>Colony-stimulating factors:</li>
        <ul>
          <li>Granulocyte-stimulating factor</li>
          <li>Macrophage-stimulating factor</li>
          <li>Granulocyte macrophage-stimulating factor</li>
          <li>Interleukin III</li>
          <li>Leukemia inhibiting factor or neuroleukin</li>
        </ul>
        <li>Transforming factor, beta</li>
      </ul>
      <h2>
        ENDOCRINE SUBSTANCES KNOWN TO INTERACT WITH THE NEURAL AND IMMUNE
        SYSTEMS
      </h2>
      <ul>
        <li>Pituitary</li>
        <ul>
          <li>Adrenal Corticotrophin-ACTH</li>
          <li>Thyrotrophin-TSH</li>
          <li>Growth hormone releasing factor-GRH</li>
          <li>Somatostatin-SS-SS</li>
          <li>Prolactin</li>
        </ul>
        <li>Adrenal Medullary Hormones</li>
        <ul>
          <li>Epinephrine</li>
          <li>Norepinephrine</li>
        </ul>
        <li>Adrenal Cortical Hormones</li>
        <ul>
          <li>Cortisol</li>
          <li>Corticosterone</li>
          <li>Aldosterone</li>
        </ul>
        <li>Thyroid Hormones</li>
        <ul>
          <li>Thyroxine</li>
          <li>Triiodothyronine</li>
        </ul>
        <li>Growth Hormones</li>
        <ul>
          <li>Somatotropin</li>
          <li>Somatomammotropin</li>
          <li>Somatomedin</li>
        </ul>
        <li>Thymus</li>
        <ul>
          <li>Thymulin</li>
          <li>Thymosin</li>
          <li>Thymopoietin</li>
          <li>Thalmic factor X</li>
        </ul>
        <li>Others</li>
        <ul>
          <li>Estrogen</li>
          <li>Testosterone</li>
          <li>Insulin</li>
        </ul>
      </ul>
      <h2>References</h2>
      <ul>
        <li>
          Beal, Myron, D.O., FAAO, 1995-96 Yearbook, Osteopathic Vision,
          American Academy of Osteopathy, 1996.
        </li>
        <li>
          A.A. Buerger, Ph.D., Philip E. Greenman, D.O., Empirical Approaches to
          the Validation of Spinal Manipulation, 1985, published by Charles C.
          Thomas.
        </li>
        <li>
          D. Thomas Collins, S. Strauss, “Somatic Sympathetic Vasomotor Changes
          Documented by Medical Thermographic Imaging During Acupuncture
          Analgesia“, Clinical Rheumatology, 1992, 55-59.
        </li>
        <li>
          Richard G. Gillette, Ronald C. Kramis, William J. Roberts, ”
          Sympathetic activation of cat spinal neurons responsive to noxious
          stimulation of deep tissues in the low back“, Pain , 1994, 56, 31-42.
        </li>
        <li>
          Ulf Lundberg, ” Methods and application of stress research“,
          Technology and Health Care, 1995, 3-9.
        </li>
        <li>
          Shin-Ichiro Nakamura, Kazuhisa Takahasi, Yuzuru Takahashi, Masatsune
          Yamagata, Hideshige Moriya, ” The Afferent Pathways of Discogenic Low
          Back Pain“, Bone and Joint Surgery, 1996, July; 78/B, 606-612.
        </li>
        <li>
          Robert C. Ward, Foundations for Osteopathic Medicine, American
          Osteopathic Association, 1997; Williams & Wilkins
        </li>
      </ul>
    </Article>
  );
};

export default ArticleNeuralBiologicalMechanisms;
