import Article from "@/components/Article";

const ArticleOmtCodes = () => {
  return (
    <Article
      title="OMT Codes"
      author="Richard A. Feely, D.O., FAAO, FCA, FAAMA"
    >
      <p>
        <em>Richard A. Feely, D.O. FAAO, FCA, FAAMA</em>
      </p>
      <h2>Coding</h2>
      <p>
        The CPT Editorial Panel ruled to include OMT codes starting in the 1994
        edition of the CPT Manual. (All{" "}
        <em>Physicians Current Procedural Terminology [CPT] </em>five-digit
        numeric codes, descriptions, numeric modifiers, instructions,
        guidelines, and other material are copyright American Medical
        Association.)
      </p>
      <p>
        Osteopathic manipulative treatment is a form of manual treatment applied
        by a physician to eliminate or alleviate somatic dysfunction and related
        disorders. This treatment may be accomplished by a variety of
        techniques.
      </p>
      <p>
        Body regions are defined as head, cervical, thoracic, lumbar, sacrum,
        lower extremity, upper extremity, pelvis, ribs, abdomen and viscera.
        (Such regions are defined in ICD-9-CM codes 739.0-739.9. This
        information should be shown on the claim form or in the physician
        record.
      </p>
      <div>
        <table>
          <tbody>
            <tr>
              <td>CPT Codes</td>
              <td>Procedure Description</td>
            </tr>
            <tr>
              <td>
                <p>98925</p>
                <p>98926</p>
                <p>98927</p>
                <p>98928</p>
                <p>98929</p>
              </td>
              <td>
                <p>OMT; one to two body regions involved</p>
                <p>OMT; three to four body regions involved</p>
                <p>OMT; five to six body regions involved</p>
                <p>OMT; seven to eight body regions involved</p>
                <p>OMT; nine to ten body regions involved</p>
              </td>
            </tr>
          </tbody>
        </table>
      </div>
      <p>
        The physician, insurance companies, Medicare, Medicaid, workers
        compensation and all other third party reimbursement systems need to
        know the following:
      </p>
      <ul>
        <li>
          These codes are to be used by physicians for osteopathic manipulative
          treatments as of January 1, 1994. It is important that all carriers,
          claims examiners and physicians be educated on the use of these codes
          so that the present confusion of coding can be resolved.
        </li>
        <li>
          These codes are separate and distinct from evaluation and management
          codes, and should be billed separately.
        </li>
        <li>
          These codes are to be used for inpatient and outpatient osteopathic
          manipulative treatment services along with the appropriate evaluation
          and management codes.
        </li>
        <li>
          These codes define the body regions appropriately for use with
          osteopathic manipulative treatments.
        </li>
      </ul>
      <h2>Using The Codes</h2>
      <p>
        These patient vignettes are designed to give specific examples of the
        types of services involved in the procedure codes for osteopathic
        manipulative treatment. Examples featuring different specialist
        physicians and surgeons are used in the examples to illustrate that any
        physician may utilize all of the codes found below. The definitions of
        body areas are found in the ICD-9 reference text under the codes 739.0
        through 739.9.
      </p>
      <p>
        After evaluating a patient and arriving at a diagnosis which includes
        somatic dysfunction it is appropriate to utilize an evaluation and
        management (E&amp;M) code to describe the evaluation and management
        service. If the diagnosis includes somatic dysfunction, the physician
        then utilizes one of the following procedure codes for describing the
        service of rendering OMT to treat the dysfunction.{" "}
        <em>
          Note that these procedure codes do not include the service involved in
          determining a diagnosis.
        </em>
      </p>
      <p>
        <strong>98925</strong> OMT to one to two body regions defined.
        <br />A 39-year-old presents to the family practitioner with right ankle
        pain following an injury. After the evaluation and assessment of the
        patient the physician arrives at a diagnosis of (1) ankle sprain and (2)
        somatic dysfunction of the right lower extremity. This is coded for by
        utilizing an appropriate E&amp;M code. The use of 98925 involves the
        treatment by the family practitioner utilizing application of
        osteopathic manipulative treatment to the right lower extremity.
      </p>
      <p>
        <strong>98926 </strong>OMT to three to four body regions defined.
        <br />A 4-year-old female presents to her pediatrician with a fever,
        cough, and sputum production. After the E&amp;M assessment and coding, a
        diagnosis of (1) bronchitis and (2) somatic dysfunction of the cervical,
        thoracic, rib and abdominal area is determined. The bronchitis is
        treated with medications. The subsequent use of 98926 involves the
        treatment by the pediatrician of the somatic dysfunction of the
        cervical, thoracic, rib and abdominal regions utilizing osteopathic
        manipulative treatment.
      </p>
      <p>
        <strong>98927 </strong>OMT to five to six body regions defined.
        <br />A 42-year-old male presents to the neurosurgeon with confusion and
        pain in the neck and upper back and exacerbation of a previous history
        of lumbar disc herniation with radiculitis following a motorcycle
        accident. After E&amp;M assessment and coding, the diagnosis is that of
        (1) closed head injury and (2) somatic dysfunction of the head,
        cervical, thoracic, lumbar, sacral and rib region. The subsequent use of
        98927 involves the treatment by the neurosurgeon of the somatic
        dysfunction of the head, cervical, lumbar, sacral and rib regions
        utilizing osteopathic manipulative treatment.
      </p>
      <p>
        <strong>98928 </strong>OMT to seven to eight body regions defined.
        <br />
        Following cholecystectomy, a 32-year-old female develops abdominal pain
        and distention. After E&amp;M assessment and coding, the attending
        physician and surgeon arrives at a diagnosis of (1 ) post-operative
        ileus and (2) somatic dysfunction of the head, cervical, thoracic,
        lumbar, sacral, ribs and abdominal/visceral regions. The subsequent use
        of 98928 involves the treatment by the surgeon of the somatic
        dysfunction of the head, cervical, thoracic, sacral, rib, and
        abdominal/visceral regions utilizing osteopathic manipulative treatment.
      </p>
      <p>
        <strong>98929 </strong>OMT to nine to ten body regions defined.
        <br />A 29-year-old female complains of generalized aching, low back
        pain and cephalgia following a vaginal delivery. After assessment of the
        patient using an E&amp;M code the family practitioner arrives at a
        diagnosis of (1 ) cephalgia and (2) post-obstetric somatic dysfunction
        of the head, cervical, thoracic, rib cage, lumbar, sacral, pelvic, and
        upper and lower extremity regions. The use of 98929 then involves the
        application by the family practitioner of osteopathic manipulative
        treatment to the head, cervical, thoracic, rib cage, lumbar, sacral,
        pelvic abdominal upper and lower extremity areas.
      </p>
      <p>
        Complete and easily understandable documentation for OMT is necessary to
        ensure adequate third party comprehension of the procedures for
        appropriate payment. Different forms of osteopathic documentation exist
        and should be reviewed for appropriate application. Available sources
        for information on terminology and codes include the Glossary of
        Osteopathic Terminology as published by the AOA, and information in CPT,
        HCPCS and ICD-9-CM.
      </p>
      <p>
        A commonly used method of documentation for OMT is illustrated in the
        use of the SOAP note. <strong>SOAP </strong>is an acronym for a format
        of recording information found during a physician visit. It includes
        Subjective complaints and histories from the patient; Objective findings
        of the physician’s exam and tests; Assessment or differential diagnosis
        based on the first two; and Plan that is the course of treatment
        designed by the physician.
      </p>
      <p>
        Somatic dysfunction is a diagnosis utilized by osteopathic physicians to
        code for disorders in the skeletal, arthrodial, myofascial and visceral
        structures as well as related vascular, Iymphatic, and neural elements.
        Palpatory findings may include, but are not limited to, tenderness,
        asymmetry, range of motion abnormalities and tissue texture changes. A
        more detailed list of terms and definitions can be found in the AOA
        Glossary of Osteopathic Terminology.
      </p>
      <p>
        In general, osteopathic manipulative techniques include, but are not
        limited to, three broad categories: soft tissue techniques such as
        stretch, gentle range of motion, and kneading; direct techniques such as
        joint mobilization, thrust and muscle energy; and, indirect techniques
        such as myofascial release, strain/counters/rain and cranial osteopathy.
        A complete list of techniques and their descriptions can be found in the
        AOA Glossary of Osteopathic Terminology.
      </p>
      <h2>New Patient</h2>
      <p>
        <strong>S</strong>
        <strong>.</strong> A 20-year-old African-American male complains of low
        back pain that began 3 days ago after he lifted a heavy object. Cannot
        straighten up when walking. Pain with change of position. Denies
        radiation of pain, it stays along the low back and waist line. Denies
        areas of numbness. Comfortable when Iying down. Aspirin helps some. Has
        used heat with some help. No prior history of back pain or injury.
        Denies allergies. Medical/surgical history is unremarkable.
      </p>
      <p>
        <strong>O.</strong> Tenderness noted over lumbar and sacral regions
        Inability to extend lumbar spine when standing Flexion posture when
        standing Muscle spasms noted in paraspinals of the lumbar region
        Decreased range of motion of lumbar spine and sacrum was noted on active
        and passive motion testing neurologic exam normal
      </p>
      <p>
        <strong>A.</strong> 1. Lumbosacral sprain/strain<strong> 846.0</strong>
        <br />
        2. Somatic dysfunction lumbar, sacral <strong>739.3 and 739.4</strong>
      </p>
      <p>
        <strong>P.</strong> 1. OMT <em>(appropriate techniques used)*, </em>
        applied to the lumbar and sacral regions
        <br />
        2. Continue aspirin
        <br />
        3. No lifting, bending or twisting
        <br />
        4. Follow up in two days to reevaluate patient progress
      </p>
      <p>Coding For This Case</p>
      <p>
        Evaluation/management; new patient <strong>99203</strong>
        <br />
        OMT two body regions; lumbar/sacral <strong>98925</strong>
      </p>
      <h2>Established Patient</h2>
      <p>
        <strong>S.</strong> Patient is here for a recheck. He states that the
        pain has decreased in his low back and that he can get around better. He
        states that he has no radiation of pain into his legs. He does state
        that he feels stiff and achy if he tries to do his normal daily
        activities. He is still taking aspirin with some relief.
      </p>
      <p>
        <strong>O.</strong> Tenderness with palpation and stretch of the erector
        spinaemuscles
        <br />
        Pain with extension and rotation left of L5
        <br />
        Pain along right Sl joint with sacral extension
        <br />
        No muscle spasms noted with active or passive range of motion
        <br />
        Negative neurologic exam of lower extremities
      </p>
      <p>
        <strong>A.</strong> 1. Lumbosacral sprain/strain; improving
        <strong> 846.0</strong>
        <br />
        2. Somatic Dysfunction, lumbar, sacral; improving{" "}
        <strong>739.3, 739.4</strong>
      </p>
      <p>
        <strong>P.</strong> 1. OMT <em>(appropriate techniques used)* </em>to
        lumbar and sacral regions
        <br />
        2. Instructed on proper posture when lifting
        <br />
        3. Increase home activities gradually and to tolerance 4. Follow up if
        improvement does not continue
      </p>
      <p>Coding For This Case</p>
      <p>
        Evaluation and management; established patient <strong>99213</strong>
        <br />
        OMT two body regions; lumbar, sacral <strong>98925</strong>
      </p>
    </Article>
  );
};

export default ArticleOmtCodes;
