import Article from "@/components/Article";

const ArticleOsteopathicHeadPain = () => {
  return (
    <Article title="Head Pain" author="Herbert C. Miller, D.O., FAAO">
      <p>Reprinted with permission of the American Osteopathic Association.</p>

      <p>
        Pain has been defined in many ways, as the sensation “resulting from the
        stimulation of specialized nerve endings,”‘ or, more poetically, as a
        punishment or penalty, as for crime. Other definitions include acute
        discomfort of body or mind, bodily or mental suffering or distress; a
        distressing sensation, as in a particular part of the body, and trouble
        experienced in doing something. (2) One’s concept of pain may be colored
        by diverse circumstances or, in scientific language, feedback. Head pain
        is usually interpreted by the clinician from the therapeutic point of
        view, that is, in terms of measures that may stop in, rather than in
        pathophysiologic terms.
      </p>

      <p>
        When analyzing head pain, the physician often prefers to look at it as a
        phenomenon or as the result of stimulation of specialized nerve endings.
        In reality, pain may be an interpretation of bodily or mental distress.
        Boshes and Arieff (3) stated:
      </p>

      <p>
        Certain aspects of pain are predicated exclusively on a neural
        substrate. Here the basis is an event or an alteration in the nervous
        system per se, as contrasted to pain caused by malignant disease,
        infected tissue, fractures or the like. Various divisions of the nervous
        system may be implicated and a description of the disability or the
        manner of posture and movement is often sufficient to enable the trained
        observer to gain an impression as to whether the pain is genuine or
        functional. Such involvement may be at the receptive, the conductive,
        the perceptive or the apperceptive level, or combinations thereof.
      </p>

      <p>
        This would appear to be a generally accepted concept, and yet head pain
        often is described and interpreted on the basis of a symptom complex
        rather than in terms of the anatomic and physiologic organization of the
        central nervous system. It is the purpose of this paper to attempt to
        describe some of the mechanisms involved in head pain and to provide
        these mechanisms with an osteopathic orientation.
      </p>

      <h2>Neural Pathways</h2>

      <p>
        Most of the sensory nerve distribution to the head and face occurs
        through the trigeminal nerve (Cr V) and fibers of cervical nerves C1,
        C2, and C3 (Fig. 1.). Smith (4) stated:
      </p>

      <p>
        The trigeminal fibers subserving pain have their neurons in the
        trigeminal or semilunar ganglion which lies in a cave of the aura mater
        in the middle cranial fossa just anterior to the apex of the petrous
        temporal bone. The peripheral branches of the trigeminal nerve, . . .
        the ophthalmic, maxillary, and mandibular nerves . . . supply a fairly
        well defined cutaneous area and broadly speaking, the deep structures
        underlying it. There is little overlap with the adjoining cutaneous
        fields of the cervical nerves….
      </p>

      <p>
        The glossopharyugeal nerve supplies common sensibility to the posterior
        third of the tongue, the pharynx, soft palate, tonsils and fauces, the
        auditory tube, the tympanic cavity and mastoid air cells, and the inner
        lining of the eardrum. The vagus nerve . . . supplies the general
        somatic afferent fibers to the posterior portion of the external
        auditory canal, part of the eardrum, and the skin of the cranial surface
        of the auricle adjoining the scalp.
      </p>

      <p>
        The pain and temperature fibers of the glossopharyngeal and vagus nerves
        relay to the nucleus of the descending trigeminal tract.
      </p>

      <p>
        The cutaneous distribution of C I is not consistent. Larsell (5) said:
      </p>

      <p>
        Occasionally it gives a cutaneous branch to the skin of the upper part
        of the back of the neck and the lower part of the scalp.
      </p>

      <p>
        The second cervical nerve chiefly supplies the area of the head and neck
        adjoining the trigeminal territory, to which the third cervical nerve
        contributes fibers. (4)
      </p>

      <p>Kimmel (5) stated:</p>

      <p>
        The nerve fibers supplying the cranial aura mater are derived from the
        trigeminal nerve, the upper three cervical nerves, and the sympathetic
        trunk. Nerve branches from the upper three cervical nerves and the
        superior cervical ganglion supply the aura mater of the posterior
        cranial fossa. The aural nerves derived from the three divisions of the
        trigeminal nerve and from the sympathetic plexuses on the internal
        carotid and middle meningeal arteries supply the remainder of the
        cranial aura mater.
      </p>

      <p>
        The first division of the trigeminal nerve supplies the aura mater in
        the anterior cranial fossa, the diaphragm sellae, nearly all of the
        cerebral falx, the tentorium cerebelli, part of the superior sagittal
        sinus, the straight sinus, the superior wall of the transverse sinus,
        and the terminal parts of the cerebral veins entering these sinuses.
      </p>

      <p>
        The maxillary division of the trigeminal nerve supplies the aura mater,
        covering the anterior part of the middle cranial fossa. Branches of the
        third, or mandibular, division of the trigeminal nerve supply the aura
        mater in the posterior and lateral parts of the middle cranial fossa and
        the aura mater lining most of the calvaria. (6)
      </p>

      <p>
        Perhaps the more important aspect of pain is that it is not a single
        identifiable entity. It may be represented by vastly complicated and
        intricate processes or by the mere experiencing of the touch of a sharp
        object. The integration of actual pain reception and perception
        represents an area of widely diverse opinion. On the basis of the
        observation that successive surgical interruptions of peripheral nerves,
        posterior roots, spinal cord, and thalamus, and ablations of portions of
        the cerebral hemispheres, may all fail to give permanent relief from
        pain, Gooddy (7) concluded that “any nervous pathways are potential
        ‘pain pathways.’ ”
      </p>

      <p>
        Pain stimuli (or at least somatesthetic stimuli interpreted as pain)
        arising from the spinal cord (C1, C2, and C3) pass principally to the
        cuneate nucleus (homolateral), synapse, cross at this level, and ascend
        to the ventrolateral nucleus of the thalamus.(8)
      </p>

      <p>Finneson (9) stated:</p>

      <p>
        The function of the thalamus is to pass impulses on to the
        cerebralcortex, and it is presumed that these impulses are integrated by
        the association nuclei in the thalamus before being relayed. The portion
        of the thalamus that projects impulses to a specific cortical area
        receives in return corticothalamic projection fibers from that area,
        forming a circuit between thalamus and cortex.
      </p>

      <p>
        Smith (4) said that pain fibers of the great auricular nerve synapse in
        the substantia gelatinosa Rolandi, from which second order neurons
        ascend in the lateral spinothalamic tract to the posteroventral nucleus
        of the thalamus. He added:
      </p>

      <p>
        Pain fibers from the trigeminal nerve have their cell bodies in the
        semilunar ganglion…. Their central processes descend, as the spinal
        tract of the trigeminal nerve, in the lateral brain stem from the upper
        pons to the C-2 level of the cord or even somewhat lower, to terminate
        in the associated spinal trigeminal nucleus which lies adjacent and deep
        to the tract. The spinal tract and the spinal nucleus correspond to and
        are continuous with the dorsolateral fasciculus of the cord and the
        substantia gelatinosa respectively.
      </p>

      <p>
        Pain afferents from the face, arriving via the trigeminal,
        glossopharyngeal, and vagal routes, relay to the portion of the spinal
        nucleus lying below the inferior limit of the fourth ventricle….
      </p>

      <p>
        Second order neurons from the spinal trigeminal nucleus cross the
        midline . . . at the ventral secondary tract to ascend on the medial
        aspect of the lateral spinothalamic tract to gain the thalamus. There is
        doubt as to the thalamic termination of these fibers. The classic view
        is that the trigeminal lemniscus (combining the ventral and dorsal
        secondary trigeminal tracts) projects to the medial portion (arcuate
        nucleus) of the posteroventral nucleus of the thalamus…. From the
        posteroventral nucleus of the thalamus, third order neurons pass in the
        sensory radiation via the posterior limb of the internal capsule to the
        somatic sensory area of the cortex in the lowest portion of the
        postcentral areas (Brodmann’s areas 3. 1. 2) just above the fissure of
        Sylvius. There is evidence of the face being represented bilaterally in
        the thalamus and cortex…. It is likely that the thalamus is responsible
        for the recognition of pain but that the perception of pain as a mental
        event requires cortical participation-probably diffuse and generalized
        cortical participation….
      </p>

      <p>
        There is also evidence that pain pathways from both cord and medulla
        relay bilaterally in the reticular formation of the brain stem and
        ascend by slow, multisynaptic routes to the medial thalamic nuclei and
        become part of the diffuse thalamic system. The latter system, which is
        thought to control the general level and direction of attention. May
        also be responsible for the affective coloring of pain.
      </p>

      <h2>Vascular Elements</h2>

      <p>
        The sensitiveness of the vascular elements has been discussed by Wolff
        (11). His investigation showed consistent sensitiveness to compression,
        stretching, and faradic stimulation in the arterial system. The great
        venous sinuses were less sensitive than the arteries to these stimuli,
        and the lesser sinuses and veins lost sensitiveness in proportion to
        their distance from the greater sinuses.
      </p>

      <p>Crosby and associates (11) stated:</p>

      <p>
        The blood vessels of the head receive their preganglionic sympathetic
        innervation from T-1 to T-2, but C-8 and T-3 and even T-4 may also
        contribute. The axons pass out into the sympathetic chain and ascend to
        synapse in the stellate and the superior cervical sympathetic ganglia.
        The postganglionic fibers distribute from the superior cervical
        sympathetic ganglion with the external and internal carotid arteries to
        the head. The intracranial postganglionics follow along the internal
        carotid artery to the circle of Willis and along branches of the
        external carotid and distribute to the adventitia and the smooth muscle
        of intracranial vessels, including arterioles of the pie mater, but not
        to the blood vessels in the brain substance. Postganglionic fibers also
        distribute to the middle meningeal artery. The plexuses along the common
        carotid and the internal carotid are not continuous with those on the
        external carotid, so that stripping the plexuses from the common and
        internal carotids will not destroy the sympathetic supply to the blood
        vessels of the face and the head. Postganglionic fibers from the
        stellate ganglion ascend along the vertebral arteries and the basilar
        artery….
      </p>

      <p>
        A parasympathetic innervation to some of the blood vessels of the head
        likewise has been demonstrated. Preganglionic parasympathetic fibers of
        the facial nerve turn off in the region of the geniculate ganglion to
        run in the great superficial petrosal nerve to the plexus on the
        internal carotid artery. Postganglionic fibers from small clusters of
        ganglion cells on the blood vessels distribute as vasodilators of the
        vessels.
      </p>

      <p>
        The vascular tone (sympathetic-parasympathetic influence) appears to be
        mediated through the forebrain with connections in the hypothalamic
        nuclei. Crosby and associates (11) wrote:
      </p>

      <p>
        The pathways by which these impulses are discharged to hypothalamic and
        midbrain segmental areas . . . constitute the various
        cortico-hypo-thalamic . . . systems and the cortico-thalamo-hypothalamic
        tracts by way of the dorsomedial thalarnic nucleus.
      </p>

      <p>
        It seems probable, as others have suggested, that the cortical paths are
        regulatory over the hypothalamic systems…. The pathways in general
        provide for emotional accompaniments to cortically initiated motor
        responses carried over pyramidal and extrapyramidal systems. . . .
        Evidence has been forthcoming that pyramidal as well as extrapyramidal
        systems carry corticofugal fibers for autonomic centers of the spinal
        cord.
      </p>

      <p>
        Before proceeding to a discussion of the types of stimuli that may be
        interpreted as pain, the character of nerve endings present in the
        meninges and associated structures of the head and neck should be
        considered in order to clarify the types of stimuli that may give rise
        to pain. Crosby and associates (11) wrote:
      </p>

      <p>
        The sensory terminations in the aura have been studied by various
        observers…. The nerve endings at the base of the skull are less numerous
        than on the convexity. They are in the form of end-branches knob- or
        club-shaped terminations, or are like balls of twine.
      </p>

      <p>
        They reported that Meissner corpuscles are associated with the finest
        tactile sensation. The Golgi-Mazzoni receptor is said to be a pressure
        receptor, of similar function to the Pacini corpuscle. The Krause
        corpuscle has been associated with discrimination of low temperatures.
        It has been suggested (11) that it may function to distinguish cool
        rather than cold. Ruffini end organs appear to serve in more than one
        type of receptor. The larger Ruffini endings serve as pressure endings,
        while smaller endings of this type are present in the subcutaneous
        connective tissue and are regarded as receptors of warmth. (11) Golgi,
        Meissner, and Pacini corpuscles have been described as receptors of
        discrimination in joint motion. They are credited with reporting motion
        characteristics in regard to rate of position change, direction of
        motion, and force required to produce position change. (12)
      </p>

      <h2>Characteristics</h2>

      <p>
        Now that the involved circuitry has been described, pain itself may be
        considered. Pain may result directly from factors originating outside
        the body (a sharp object or excessive heat), from pathophysiologic
        changes within the body (sustained muscle tension or a tumor) or from
        abnormally mediated psychologic factor~ through autonomic response. Pain
        may result from mechanical or psychologic stimulation or a combination
        of these. It may be described, then, as a response to stimuli that
        threaten tissue integrity or organizational integrity of the body unit.
      </p>

      <p>
        Various authors have classified pain according to the particular portion
        of the nervous system immediate!! Responsible for the transmission of
        the stimulus to the central nervous system. As Boshes and Arieff (3)
        said pain may be classified as being at the receptive, the conductive,
        the perceptive, or the apperceptive level, at a combination of these.
      </p>

      <p>
        Pain must be discerned as a local, projected, or referred phenomenon.
        Localized pain is restricted to the immediate area of reception, as in
        pain in a toot from an apical abscess. Projected pain in the head may be
        exemplified by trigeminal neuralgia, which Magoun (13) stated is . . .
      </p>

      <p>
        apparently due to restriction in the aural investiture of the root as
        passes over the petrous ridge, in Meckel’s cave housing the ganglia or
        in the sleeves around the three branches as they exist from the skull.
      </p>

      <p>
        ain is projected at times over the entire hemiface served by the nerve.
        Referred pain may be exemplified by reference to the face of thrombosis
        of the posterior inferior cerebellar artery. (4)
      </p>

      <p>
        Although these classifications of pain overlap to some degree, the use
        of a combination of classification helps to explain various phenomena of
        pain production. The Patient waiting for the attention of the dentist or
        surgeon may suppress pain mentally and say, “It doesn’t hurt as it did
        yesterday,” until the approach of the time for local anesthetic
        preparation. Then a touch by any object may produce a unique response in
        the area of attention. The apperceptive mechanisms, mediated through the
        nuclei of the thalamus and modified through the cortifugal control
        systems of the cerebellum, (14-17) plus the pituitary-adrenal
        hyperfunction due to fear, cause pain uniquely individualized by the
        patient’s level of apprehension. The cortifugal controls exerted through
        the cerebellum modify the intensity of activity occurring both on a
        motor level and through the thalamic nuclei. It appears that damage to
        or suppression of the control system may be responsible for the
        rigidity, hyperactivity, dysmetria, ataxia, and epileptiform activity
        exhibited by patients with brain damage or trauma.(15)
      </p>

      <p>
        Sutherland (18) described his observations and conclusions in reference
        to stress mechanisms involving the aura mater and cranial sutures. The
        observations of the various types of nerve endings in the leptomeninges
        make the information supplied by stress on the aura mater and pie mater
        available to the centers of perception, apperception, and motor
        activity. It has been demonstrated (19) that the recurrent meningeal
        nerves in the spinal area (especially the branches that enter through
        the foremen magnum along with the internal carotid artery) are derived
        from the sympathetic trunk and supply the aura mater lining the
        posterior cranial fossa. This distribution makes available to this area
        information from the outer layers of the cranial aura mater, which forms
        the periosteum of the cranium, and the inner layer, which forms the
        investing aura of the brain (the tentorium cerebelli, falx cerebri, and
        falx cerebelli), and from the spinal cord meninges and supporting
        ligaments.
      </p>

      <p>
        Ray and Wolff (20) in 1940 studied the probable causes of headache or
        head pain in relation to the aura mater from observations made on 30
        patients during surgical procedures on the head; they concluded that the
        pains result primarily from inflammation, traction, displacement, and
        distention of pain-sensitive structures, of which cranial vascular
        structures are most frequent and widely distributed. Unfortunately, they
        failed to mention until Wolff’s later work (10) that the actual pain
        sensitive nerve endings are located in the aura mater, the arachnoid,
        and the pie mater supporting the vascular structures. These factors cast
        new light on the observations of Sutherland, especially since the aura
        mater on the internal surface of the cranium is continuous with the
        periosteum of the head.
      </p>

      <p>
        No studies have been published to support the possibility of a strain
        gauge type of reporting across the sutures, but the observation of the
        sensory distribution to the internal and external surfaces of the
        cranial vault would appear to make such an arrangement feasible. (4, 6)
      </p>

      <p>
        The information available indicates that essentially the same types of
        stimuli elicit painful reactions whether they arise inside or outside
        the cranium. Psychologic modification, through mechanisms mentioned, is
        most likely to affect those areas of reception most easily observed
        through the special senses, such as sight and hearing.
      </p>

      <p>
        Since involvement of the special senses introduces the possibility of
        modification of afferent stimuli by the limbic system, Aird (21) stated:
      </p>

      <p>
        Neurophysiologic evidence has suggested that this portion of the nervous
        system is concerned with smell, taste, and other special senses, the
        gastrointestinal system and other autonomic functions, and behavioral
        reactions.
      </p>

      <p>
        This brings pain into the area of psychoneurophysiologic processes of
        reception, conduction, and perception to the stage of apperception or
        total integration of the process of interpreting pain, and a possible
        introduction of the subject of pain threshold (which is beyond the scope
        of this paper).
      </p>

      <p>
        It should be mentioned that there are definite interrelations between
        the cortifugal system, mentioned earlier, and the limbic system, which
        as yet are not clearly defined.
      </p>

      <h2>Osteopathic Approach</h2>

      <p>
        The foregoing discussion has described the circuitry necessary for the
        identification and response to head pain. Feedback mechanisms necessary
        to establish a cybernetic model have been outlined. On the basis of this
        description it should not be difficult for the knowledgeable physician
        to apply therapeutic measures. The knowledgeable osteopathic physician
        possesses the palpatory skills to intervene directly in the
        pathophysiologic process. Pain in the head, through the mechanism
        described, produces palpable reflex area or tissue response, in the
        superficial tissues such as the skin, the muscle, and deep connective
        tissues. By discriminatory palpation he can determine the relative
        duration or stage of chronicity of the condition and apply therapy.
      </p>

      <p>
        Hoover (22-25) has written extensively and descriptively in regard to
        application of technique to the various ages or stages of the process
        involved in stress. He described a functional technique as opposed to
        structural technique. By this technique the physician may affect the
        established cybernetic system by entering the system as an aid in
        diminishing the stress system established. In this mode of treatment
        enough force is exerted, through the various planes of motion of
        accommodation of the tissue or articulation, to bring the structures
        involved to a point of what Hoover called “dynamic reciprocal balance.”
        (25) In this way the physician establishes a servocybernetic system
        which allows the tissue or articulation to establish a new state of
        equilibrium within the limits of its ability to accommodate
        physiologically. Hoover (24) stated:
      </p>

      <p>
        Treatment by functional technic depends upon and is directed by the
        reaction of a part of the patient to demands for activity made upon that
        part.
      </p>

      <p>
        By the recruitment of the demonstrable changes in tissue and its
        activity, it is possible for the palpating hand to discern the
        cybernetic mechanisms involved in the origin of head pain.
      </p>

      <p>Harvey (25) stated:</p>

      <p>
        A basic cybernetic mechanism is “feedback.” This is the process of
        transferring energy or information from the output of a circuit to its
        input and is a generally accepted control mechanism in all types of
        self-regulating systems that use closed-loop, negative feedback
        networks.
      </p>

      <p>
        I have not found active and passive joint motion palpation to be
        sufficiently discriminating in the analysis of such cybernetic
        mechanisms to allow me to enter into a servocybernetic relation with the
        patient on a therapeutic level. After observation of several highly
        skilled osteopathic physicians in their approaches to palpation and
        treatment of a wide variety of pathophysiologic processes and syndromes,
        a method of diagnostic palpation became apparent. As the newly found
        method was used, its applications and uses began to reveal themselves,
        and this continues. Articles (27, 28) have been published by two of the
        highly skilled physicians whose work has been observed. The use of the
        principles presented by these physicians allows one to determine the
        area or areas of stress and the character of the assault involved and to
        counteract their deleterious effects.
      </p>

      <p>
        The previous discussion of mechanisms in the central nervous system
        covered what is presently known of the circuitry involved in feedback
        mechanisms of the human body in relation to head pain. After the
        physician has determined the areas of stress and the character of the
        assault, he bases his treatment on the counterbalancing of the stress
        forces, that is, changing the characteristics of the input and feedback,
        so as to create a servocybernetic system. Establishing controlled input
        alters the level of control influence exerted by the negative feedback
        network.
      </p>

      <p>
        The completion of treatment for any particular time is signaled by
        improved physiologic reaction of the tissues involved, that is, an
        increase in activity in hyperactive tissue, and a synchronous motion
        (internal or external rotation; flexion or extension) with the basal
        respiratory cycle or primary respiratory mechanism, as defined by
        Magoun. (13) This allows the patient to establish a new level of
        homeostasis compatible with his or her ability at any particular time to
        recover from the original assault.
      </p>

      <p>
        Stress patterns of considerable duration complicated by numerous
        overlying injuries have responded in a surprising manner to treatment
        applied in this manner.
      </p>

      <h2>Case Report</h2>

      <p>
        A 44-year-old white woman was admitted to the hospital with a chief
        complaint of severe headaches, which occurred in the left occipital area
        and radiated to the left temporal bone and vertex of the skull. The
        headaches were associated with nausea and vomiting. Their onset was
        associated with an automobile accident that had occurred six years
        before this admission. Following the accident hemianesthesia involving
        the left arm, leg, and side of the face developed. At that time the
        patient had been hospitalized for 22 days. Her condition improved with
        bed rest, but she had not been freed of pain, and paresthesia of the
        left arm, leg, and side of the face remained. She was unable to turn
        from a supine position to a left lateral recumbent position. It was not
        clear whether this was due to weakness, loss of proprioception, or loss
        of motor control. The patient had spent a total of 66 days in the
        hospital over the next two years for paresthesia of the left side of the
        body and headache (hemicephalgia on the left). The patient said that she
        had not been unconscious at the time of or after the accident. There was
        no familial history of neurologic disease or headache.
      </p>

      <p>
        During the six years after the accident the patient had received nearly
        every know type of therapy for cephalgia and migraine, including
        administration of narcotics and adrenocorticoids and trigger-point
        injections.
      </p>

      <p>
        The patient’s surgical history included appendectomy, cesarean section,
        and total hysterectomy. Neurological examination did not demonstrate any
        abnormality, and the cellular structure of the cerebrospinal fluid and
        the chemical contents were not remarkable. The pressure of cerebrospinal
        fluid was in the middle of the normal range, and the Queckenstedt test
        did not show abnormality. Laboratory tests, including complete blood
        count, measurement of fasting blood sugar an creatinine, urinalysis, and
        the VDRL test for syphilis at the time of admission and discharge showed
        no abnormality. X-ray examination at the time of admission showed what
        appeared to be an articulation between the posterior tubercle of the
        posterior arch of the atlas an the occiput, and a decrease of the normal
        lordotic curvature of the cervical spine, that is, a reversal the normal
        cervical curve.
      </p>

      <p>
        After a week’s hospitalization, I was called in consultation, and my
        examination elicited the following additional findings: decrease in
        backward bending the cervical spine, decrease in mobility in all
        direction through the occipito-atlanto-axial articulation flattening of
        the cervical lordotic curvature, bilateral compression through the
        sacroiliac articulation sphenobasilar compression of the cranial
        mechanic, with vertical strain (spheroid high), side bending rotation,
        with convexity to the left, and slight torsion on the right. The entire
        paravertebral mass from occiput to sacrum was under extreme tension.
      </p>

      <p>
        The findings were compatible with the following diagnosis: Spinal
        ligamentous strain and sprat (spheroid high), left side bending
        rotation, and right torsion of the cranial mechanism. Treatment was
        directed at relieving the stress on the meninges an vascular channel
        throughout the cranial sacral mechanism to reduce edema, muscle tensions
        and spasm and to reduce the level of afferent CNS input to establish a
        more physiologic level of function.
      </p>

      <p>
        Both cranial treatment and fascial release technique were directed to
        the sphenobasilar vertical strain suboccipital area, and sacrum because
        of the hyperirritability of these tissues and their inability to react.
        The patient was not treated again for 48 hours because of other demands
        on the physician’s time. At the second treatment the tissue reaction was
        much improved, an the patient could withstand deeper treatment to the
        involved area without excessive pain or tissue reaction After this
        treatment the patient’s cervical spine was reexamined
        roentgenologically, and the films showed that the posterior arch of the
        atlas was no longer in contact with the occiput and that there was
        improvement in the cervical anteroposterior curvature. The patient’s
        pain decreased over the next 24 hours, and she was released from the
        hospital to be seen at my office within 48 hours. The patient was seen
        twice a week for the next three weeks. At the end of this time the
        patient had been free of pain for approximately 10 days, end that length
        of time between treatments was extended to, a week.
      </p>

      <p>
        As the patient’s tissue response improved, the interval between
        treatments was lenghtened correspondingly, without recurrence of severe
        headaches until her daughter, who had a congenital cardiac valvular
        lesion, told her parents she was pregnant. Headaches recurred, but
        responded well to treatment. They recurred frequently but were
        terminated on the arrival for a normal healthy granddaughter. At the
        time of this report the patient still was seen on occasion for
        maintenance and preventive treatment
      </p>

      <h2>Treatment Discussion</h2>

      <p>
        The treatment of this patient was carried out according to the
        principles already described.
      </p>

      <p>
        After routine physical examination a thorough palpatory examination was
        carried out. Palpation began at the sacral area. With the patient in the
        supine position, her sacrum was cupped in the examiner’s left hand, with
        the first finger extending over the right sacroiliac articulation to
        make contact with the right iliolumbar ligament (lower portion). The
        little finger was placed at the left sacroiliac articulation and the
        second and third fingertips placed just lateral to the tip of the
        spinous process of the fifth lumbar segment of the spine. Light
        palpation demonstrated relatively little activity of the tissues. When
        palpation was deepened it demonstrated a rigidity of the ligamentous
        structures supporting the sacroiliac articulations both anteriorly and
        posteriorly and extreme tension through the iliolumbar ligaments
        bilaterally.
      </p>

      <p>
        The examining procedure is as follows: Light palpation is carried out
        with light contact with skin. The depth of palpation is increased by
        establishing a fulcrum and gently increasing the tension or pressure
        distal to the fulcrum so that the palpating hand may remain relaxed and
        be used as a palpating instrument rather than attempting to constantly
        monitor its own proprioceptive phenomena. The pressure is gently
        increased until reaction is stimulated in the layer of tissue the
        examiner wishes to palpate. The resulting tissue reaction will
        demonstrate to the examiner the resultant force (the summation of the
        various forces exerted at the time of injury) that elicited the
        protective reaction of the tissues under examination.
      </p>

      <p>
        The transition from examination to treatment is a matter of following
        the resultant force to the point of dynamic reciprocal balance and
        maintaining this balance until the tissues complete their accommodation.
        This accommodation is accompanied with increased tissue relaxation, a
        feeling of increased tissue vitality, and a longitudinal to-and-fro
        motion corresponding to the primary respiratory cycle.
      </p>

      <p>
        If continued force is applied to the injured tissues after the immediate
        response, the ensuing fatigue may result in an adverse or excessive
        reaction of the treated tissues, which appears to create a type of
        kinesthetic shock (a dissociation of the proprioceptive motor feedback
        mechanism resulting in a loss of coordinated, previously programmed or
        learned motion patterns with an increase in sensitiveness and possibly
        pain in the particular ligaments and connective tissues. This causes
        gait or motion aberration that is not typical of the individual. This
        usually occurs in a single member or limb or segment of such member or
        limb.
      </p>

      <p>
        Each area found to be involved in the total stress mechanism is treated
        in a similar manner, the only differences being in the method of
        application of the testing or treating forces to accommodate the
        peculiarities of anatomic structure, of the region under study and
        treatment. In the cervical area palpation is performed along the lateral
        margin of the paravertebral mass that is located over the articular
        pillar. This permits palpation of the paravertebral mass, the
        periarticular ligaments, and the reaction of the musculature attached to
        the anterior aspects of these vertebral segments. In palpation of the
        cranium, the index finger approximates the lateral aspect of the great
        wing of the spheroid; the second finger is placed posterior to the
        sphenosquamal articulation; the third finger is placed at the
        parietotemporo-occipital articulation (asterion), and the little finger
        is placed on the occiput.
      </p>

      <p>
        This contact is often altered to suit unusual injury patterns, but in
        any case the application of treatment follows the same basic principles.
        The fulcrum is usually established by crossing the thumbs. The flexor
        pollicis longus muscle of each thumb is utilized to maintain good
        contact and allow the hands to remain as relaxed as possible. Thus the
        hands may be free to move within the demonstrated force mechanisms and
        establish the dynamic reciprocal tension necessary to allow the tissues
        to overcome injury force mechanisms. The mastering of this type of
        therapeutic and diagnostic approach is not difficult but requires
        studious concentration to avoid hindering the activity of the tissues,
        so that they may reveal the stress patterns to which they have been
        subjected. The physician must remain relaxed and observant so he may
        participate in assisting the tissues to reach and maintain the point of
        dynamic reciprocal tension.
      </p>

      <h2>Comments</h2>

      <p>
        The studies reviewed here demonstrated the possibility that pain may
        arise from the neck and possibly lower levels. In many cases the
        involvement of arthrodial articulations may require more stringent or
        forceful modes of treatment than those described here. Hoover (22)
        described the use of high velocity manipulation to accomplish a
        “popping” of the joint so that the involved levels of discrimination
        must rearrange their synaptic organization in response to shock produced
        by the forceful articulatory motion. By this method a new level or at
        least a different degree of function is established.
      </p>

      <p>
        The little understood mechanisms of the central nervous system are
        slowly revealing their intricacies through the devoted efforts of many
        dedicated and curious researchers. These workers can divulge their
        observations, but it becomes the responsibility of the physician to be
        aware of their discoveries, analyze the information, and apply it
        discreetly in clinical situations. The information presented here may
        give the osteopathic physician a slightly different view and increase
        the effectiveness of his application of osteopathic manipulative therapy
        to his patient.
      </p>

      <p>
        The neuroanatomy and physiology involved in head pain have been
        discussed. Various types of input that may be characterized as pain have
        been mentioned, and mechanisms involved in the apperception as pain have
        been demonstrated. An attempt has been made to correlate the wide
        varieties of osteopathic manipulative approach to the particular
        situation in which pain is expressed in the head. A case history
        exemplifying my approach to such problems has been presented and the
        principles of treatment described.
      </p>

      <h2>References</h2>

      <p>
        Dorland’s illustrated medical dictionary. Ed. 24. W.B. Saunders Co.,
        Philadelphia, 1965
      </p>

      <p>
        1. Emery, H.G., and Brewster, K.G., editors: New century dictionary of
        the English language. Appleton-Century-Crofts, Inc., New York, 1959
      </p>

      <p>
        2. Boshes, B., and Arieff, A.J.: Clinical experience in the neurologic
        substance of pain. Med Clin North Am 52:111-21, Jan 68
      </p>

      <p>3. Smith, B.H.: Anatomy of facial pain. Headache 9:7-13, Apr 69</p>

      <p>
        4. Larsell, O.: The nervous system. In Human anatomy. By H. Morris. Ed.
        11, edited by J.P. Schaeffer. Blakiston Co., New York, 1953
      </p>

      <p>
        5. Kimmel, D.L.: The nerves of the cranial aura mater and their
        significance in aural headache and referred pain. Chicago Med Sch Quart
        22:16-26, Fall 61
      </p>

      <p>6. Gooddy, W.: On the nature of pain. Brain 80:11831, 1957</p>

      <p>
        7. Netter, F.H.: Nervous system. Vol. 1. Ciba collection of medical
        illustrations. Ciba Pharmaceutical Co., Summit, N.J., 1953
      </p>

      <p>
        8. Finneson, B.E.: Diagnosis and management of pain syndromes. Ed. 2.
        W.B. Saunders Co., Philadelphia, 1969
      </p>

      <p>
        9. Wolff, H.G.: Headache and other headpain. Ed.2. Oxford University
        Press, New York, 1963
      </p>

      <p>
        10. Crosby, E.C., Humphrey, T., and Lauer, E.W.: Correlative anatomy of
        the nervous system. Macmillan Co., New York, 1962
      </p>

      <p>
        11. Korr, I.M., and Buzzell, K.A.: Personal communication to the author
      </p>

      <p>
        12. Magoun, H.I.: Osteopathy in the cranial field. Ed.2. Journal
        Printing Co., Kirksville, Mo., 1966
      </p>

      <p>
        13. Steriade, M.: The cerebello-thalamo-cortical pathway. Ascending
        (specific and unspecific) and corticofugal controls. Int J Neurol
        7:177-200,1970
      </p>

      <p>
        14. Gerstenbrand, F., et al.: Cerebellar symptoms as sequelae of
        traumatic lesions of upper brain stem and cerebellum. Int J Neurol
        7:271-82, 1970
      </p>

      <p>
        15. Snider, R.S., Mitra, J., and Sudilovsky, A.: Cerebellar effects on
        the cerebrum. A microelectrical analysis of somatosensory cortex. Int J
        Neurol 7:141-51, 1970
      </p>

      <p>
        16. Ito, M.: Neurophysiological aspects of the cerebellar motor control
        system. Int J Neurol 7:162-76, 1970
      </p>
    </Article>
  );
};

export default ArticleOsteopathicHeadPain;
