import Article from "@/components/Article";

const ArticleOsteopathicManipulationInPregnancy = () => {
  return (
    <Article
      title="Osteopathic Manipulation in Pregnancy"
      author="Andrea S. Clem, D.O."
    >
      <h2>Overview</h2>
      <p>
        During pregnancy, a woman’s body undergoes many anatomic (structural),
        circulatory (fluid), and hormonal changes that may lead to various
        musculoskeletal complaints, increase her risk of injury, or alter the
        course of pre-existing conditions. Some of the more common complaints
        include low back and pelvic pain, carpal tunnel syndrome, headache,
        nausea, vomiting, and edema. Approximately 2/3 of women with rheumatoid
        arthritis will have improvement in their symptoms during pregnancy but
        may suffer a flare-up in the post partum period. Many women with
        ankylosing spondylitis may have an exacerbation of symptoms. Women with
        scoliosis have no increased risk over non pregnant women for
        progression. [1,2]
      </p>

      <p>
        Most of the symptoms encountered can be attributed to the development
        and growth of the fetus and are often specific to the different
        trimesters of the pregnancy. Osteopathic manipulation can play an
        important role in providing relief for the common complaints throughout
        the various stages of pregnancy, delivery, and the post partum period.
      </p>

      <h2>First Trimester</h2>
      <p>
        Common conditions in the first trimester include heartburn as well as
        nausea and vomiting (“morning sickness”). Structural dysfunction is
        often found at the spinal levels related to the nervous system supply to
        the organs involved. Osteopathic manipulation to the cervical and
        thoracic spine can be used to influence these nervous system inputs,
        providing relief for gastrointestinal complaints. [3]
      </p>

      <h2>Second Trimester</h2>
      <p>
        As the uterus increases in size, pain may be felt through the round
        ligaments and the pubic symphysis. Once it expands from the pelvis in to
        the abdomen, the diaphragm becomes elevated affecting breathing. Fascial
        release through the abdomen, ribcage, and diaphragms may improve
        respiration and prevent or alleviate backache, sciatica, cramps or
        posterior pelvic pain. The second most common complaint in the second
        trimester is hand and wrist pain resulting from localized swelling.
        Anywhere from 1% -25% of all pregnant women may exhibit the classic
        carpal tunnel syndrome symptoms of numbness, tingling, and night-time
        pain. Since it almost always resolves after delivery, conservative
        treatment is recommended. This would include night time splinting and
        manipulative treatment aimed at improving lymphatic flow and releasing
        tension at the wrist. [1,3]
      </p>

      <h2>Third Trimester</h2>
      <p>
        Mechanical and structural changes are at their greatest in the third
        trimester. These result in changes in gait, loss of balance, and low
        back pain. Gravitational effects from the uterus in the abdomen and
        pelvis cause pressure that decreases lymphatic and venous return from
        the lower extremities leading to edema and hemorrhoids. Constipation and
        reflux are also common. Osteopathic manipulation to the pelvic floor and
        mid thoracic and lumbar spine helps to mobilize fluid and relieve these
        complaints.
      </p>

      <h2>Labor &amp; Delivery</h2>
      <p>
        During labor, Osteopathic manipulation focused at the lower thoracic and
        lumbar areas can influence the nerves that supply the pelvic organs.
        Soft tissue and myofascial treatment of the pelvis and sacrum can help
        to maintain good mobility of the sacrum, allow for proper rotation and
        descent of the fetal head, and influence cervical dilation. Osteopathy
        in the Cranial Field has been shown in studies to influence uterine
        contractility and help to overcome uterine inertia by its effect on the
        pituitary secretion of oxytocin. [4, 5]
      </p>

      <h2>Post Partum</h2>
      <p>
        Throughout pregnancy, a woman’s body produces the hormone relaxin. This
        allows the joints of the pelvis to become flexible for the fetus to
        pass. It is also responsible for the increased joint laxity that can
        lead to the dysfunctions that occur during pregnancy and delivery. Since
        the serum levels of relaxin return to near normal three days post
        partum, treatment immediately after delivery can help to re-align the
        sacropelvic structures that have just undergone the stress of pushing
        and positioning in stirrups. Later follow-up with osteopathic
        manipulation is useful for the treatment of any persistent pain in the
        low back or pelvis.
      </p>

      <h2>Contraindications</h2>
      <p>
        In most cases, the use of Osteopathic manipulation in pregnancy is both
        safe and effective. Conditions where it should not be used include:
        premature labor, abruption placentae, rupture of membranes without
        labor, incompetent cervix, eclampsia, and ectopic pregnancy. 5
      </p>

      <h2>Summary</h2>
      <p>
        Pregnancy is a time where a women’s body undergoes many changes-often
        resulting in some form of musculoskeletal complaint. Osteopathic
        manipulation can serve as a valuable adjuvant therapy in the normal
        obstetrical care. By providing relief from pain, maintaining homeostasis
        and circulation, and supporting labor and delivery, pregnancy can be a
        more comfortable and enjoyable experience.
      </p>

      <h2>References</h2>
      <p>
        1. Ireland M, Ott S. The Effects of Pregnancy on the Musculoskeletal
        System. Clinical Orthopaedics and Related Research. 2000. 372:169-179.
      </p>
      <p>
        2. Jones A, Lockwood M. Osteopathic Manipulative Treatment in Pregnancy
        and Augmentation of Labor: A Case Report. AAO Journal. 18:1 March 2008:
        27-29.
      </p>
      <p>
        3. Ward R. Foundations for Osteopathic Medicine. 2nd ed. Philadelphia,
        PA: Lippincott Williams &amp; Wilkins; 2003: 450-461.
      </p>
      <p>
        4. McAfee S, Chila A. Occipital Compression and its Potential Uses in
        Obstetrics. AAO Journal. 17:3 September 2007: 27-29.
      </p>
      <p>
        5. DiGiovanna E, Schiowitz S, Dowling D. An Osteopathic Approach to
        Diagnosis and Treatment 3rd ed. Philadelphia, PA: Lippincott Williams
        &amp; Wilkins; 2005: 651-659.
      </p>
    </Article>
  );
};

export default ArticleOsteopathicManipulationInPregnancy;
