import Article from "@/components/Article";

const ArticleOsteopathicManipulativeTreatment = () => {
  return (
    <Article
      title="Osteopathic Manipulative Treatment"
      author="Richard A. Feely, D.O., FAAO, FCA, FAAMA"
    >
      <p>
        In an era marked by medical advances, from state-of-the-art surgery to
        the newest prescription medication, what unique tool will osteopathic
        physicians use? Their hands.
      </p>

      <p>
        Osteopathic physicians (D.O.s) provide you with all the best that
        medicine has to offer. They can specialize in any recognized area of
        medicine, from pediatrics to neurosurgery. However, their knowledge and
        use of the latest medical technology is complemented by their
        application of a hands-on treatment tool known as osteopathic
        manipulative treatment, or OMT.
      </p>

      <p>
        Using OMT, D.O.s bring an added dimension to healthcare, in the form of
        a non-invasive treatment. D.O.s use OMT to diagnose, treat and even
        prevent illness or injury. When appropriate it can be used in
        conjunction with, or in place of, medication or surgery.
      </p>

      <h2>Unique Philosophy</h2>

      <p>
        D.O.s are widely recognized for their incorporation of manipulative
        medicine into their spectrum of care. OMT is just one element of the
        unique philosophy of osteopathic medicine.
      </p>

      <h2>The Big Picture</h2>

      <p>
        By taking the whole person approach to care, D.O.s don’t just focus on
        the disease or injury. They look for the underlying causes of disease
        instead of simply treating the symptoms. Not only do they consider your
        physical condition, but also they take other factors into account like
        home, work and family life when making a diagnosis.
      </p>

      <p>Patient, Heal Thyself</p>

      <p>
        D.O.s recognize that the body is inherently capable of healing itself,
        though it must constantly fight physical, emotional and nutritional
        “stressors” to maintain a state of wellness. D.O.s believe in educating
        you about good health and prevention of disease.
      </p>

      <h2>The Musculoskeletal System</h2>

      <p>
        D.O.s place particular emphasis on the musculoskeletal system, which
        comprises two-thirds of the body’s mass. D.O.s believe that all of the
        body’s systems, including the musculoskeletal system, work together and
        that disturbances in one system may impact function elsewhere in the
        body. This understanding of body structure and function provides the
        foundation for the osteopathic approach to medicine.
      </p>

      <h2>The ABC’s of OMT and How It Can Work for You</h2>

      <p>
        OMT is predicated upon your D.O.’s knowledge of medicine. Once your D.O.
        has ruled out mechanical causes for your illness or injury (through
        blood and urine testing, X-rays, etc.), and based upon physical and
        mechanical findings, your D.O. may decide to utilize OMT. While it is
        commonly associated with physical ailments such as low back pain, this
        modality can also be used to relieve the discomfort or musculoskeletal
        abnormality associated with a number of disorders, including: asthma,
        sinus disorder, carpal tunnel, migraines and menstrual pain.
      </p>

      <p>
        The osteopathic approach to treating many diseases includes medication
        and/or surgical intervention, plus OMT. OMT can relieve muscle pain
        associated with a disease and can hasten your recovery from illness by
        promoting blood flow through tissues.
      </p>

      <h2>Diagnosis</h2>

      <p>
        Your structural exam will begin with an assessment of your posture,
        spine and balance. Your D.O. will then use his fingers to palpate your
        back and extremities. Your D.O. will then use his fingers to palpate
        your back and extremities. He will also check your joints for
        restriction and/or pain during motion as well as check your muscles,
        tendons and ligaments where tenderness can signal a problem. Through
        extensive osteopathic training in manipulative medicine, D.O.s can
        detect changes in tissue, however small, that signal injury or
        impairment.
      </p>

      <p>
        Once the structural exam is complete, your D.O. will integrate this
        information with your medical history and a complete physical exam.
        After that point, a treatment plan can be established.
      </p>

      <h2>Treatment</h2>

      <p>
        Using a variety of OMT techniques, your D.O. will apply manual forces to
        your body’s affected areas to treat structural abnormalities and will
        then apply specific corrective forces to relieve joint restrictions and
        misalignments. Based upon the severity of your problem, you may require
        more than one treatment.
      </p>

      <h2>Case 1</h2>

      <p>
        Mary visited her D.O. complaining of a sharp pain in her side. The
        physician asked a series of questions about her pain: its intensity,
        onset and duration. They also discussed her medical history. The
        physician then ordered a series of tests to determine whether the pain
        was caused by disease (i.e. gallbladder or appendix). Tests revealed
        that it was not. Since the patient indicated that she worked in an
        office with a “surround style” desk, the D.O. considered that Mary might
        be suffering from postural/mechanical strain. Based upon his
        examination, interview with the patient and negative test results, the
        physician decided to employ OMT to relieve motion restrictions and
        muscle strain caused by improper sitting and movement. He also
        recommended changes in the set-up of her workstation to alleviate
        further pain.
      </p>

      <h2>Case 2</h2>

      <p>
        Michael’s symptoms included cough, congestion, fever and headache.
        Suspecting chronic sinusitis, his D.O. conducted an exam and ordered
        appropriate tests. When results confirmed the diagnosis, the physician
        prescribed an antibiotic to treat the infection. She also employed a
        variety of OMT techniques to promote sinus drainage and relieve pain
        related to the infection. Michael’s congestion was markedly reduced
        after just one OMT session. Upon completion of his antibiotic therapy
        two weeks later, his infection was eliminated.
      </p>

      <h2>Who Can Benefit</h2>

      <p>
        People of all ages and backgrounds have found relief from pain and
        dysfunction as well as improved mobility through OMT. D.O.s incorporate
        this modality into their treatment plans for top athletes and
        performance artists, workers with on-the-job injuries and thousands of
        people, just like you.
      </p>

      <h2>Proof Positive</h2>

      <p>
        A study published in the November 4, 1999 issue of the New England
        Journal of Medicine confirms what D.O.s have known for years’ that OMT
        works. In this case, researchers examined the effectiveness of OMT for
        treating low back pain.
      </p>

      <p>
        Patients were divided into two groups’ one treated with standard options
        like hot/cold packs, physical therapy and anti-inflammatory medication
        while the other group received OMT and standard care. After a
        twelve-week period, patients in both groups showed improvement. However,
        researchers learned that the patients receiving OMT required less
        medication and physical therapy, resulting in less side effects and
        lower health care costs.
      </p>

      <p>
        Another study released on OMT revealed its effectiveness in reducing
        pain after a hysterectomy. Researchers measured the amount of morphine
        to treat patients’ pain as well as their perception of their pain
        levels. Upon the study’s completion, it was determined that
        administering OMT significantly reduced patients’ needs for pain
        medication.
      </p>

      <p>
        By incorporating OMT into their practice of complete medicine, D.O.s are
        providing the most comprehensive care available today.
      </p>

      <h2>History</h2>

      <p>
        The earliest medical writings from centuries past describe the efficacy
        of manual medicine. In 1874, osteopathic medicine’s founder, Dr. A.T.
        Still, recognized the power of hands-on care and incorporated it into
        his philosophy of medicine. Dr. Still identified the musculoskeletal
        system as a key element of health; he recognized the body’s self-healing
        capacity; he emphasized prevention, exercise and keeping fit; and he
        identified palpation and human touch as vital and less intrusive
        elements of diagnosis and treatment. As the impressive growth of
        osteopathic medicine demonstrates, Dr. Still’s founding tenets have
        withstood the test of time and scientific scrutiny.
      </p>

      <h2>Education</h2>

      <p>
        D.O.s complete four years of medical training at one of the nation’s
        fully accredited colleges of osteopathic medicine. The osteopathic
        curriculum is intensive and broad-based. It includes comprehensive
        training in the musculoskeletal system and the use of OMT. Manipulation
        combined with the osteopathic principles of holistic care, prevention
        and primary care makes osteopathic medicine unique.
      </p>

      <p>
        Upon graduation from medical school, D.O.s complete a one-year rotating
        internship through all the areas of primary care. Afterwards, they may
        complete a residency in any of more than 120 specialty and subspecialty
        areas of medicine. However, sixty-four percent of all D.O.s remain in
        primary care practices.
      </p>
    </Article>
  );
};

export default ArticleOsteopathicManipulativeTreatment;
