import Article from "@/components/Article";

const ArticlePediatricDigestiveProblems = () => {
  return (
    <Article
      title="Digestive Problems"
      author="Richard A. Feely, D.O., FAAO, FCA, FAAMA"
    >
      <p>
        Newborn babies are frequent sufferers of gastrointestinal complaints.
        That shouldn’t come as a surprise when one considers that the digestive
        system had no job to do in those first nine months in utero but is asked
        to be responsible for the entire sustenance of the body after birth.
        Digestive system troubles can range from spitting up to projectile
        vomiting and reflux, from mild difficulty burping to the hours of daily
        crying of a colicky baby. Although these problems do lessen as the
        digestive system matures, waiting for relief can be very hard on infants
        and parents.
      </p>

      <p>
        Osteopathic manipulative treatment, which improves body function through
        correcting body structure, can have a significant role in assisting in
        the resolution of the digestive system distress of infancy. The troubles
        often have their origin when a difficult birth experience irritates the
        vagus nerve which controls much of the digestive system. When the bony
        misalignment and tissue tensions affecting the nerve are removed, the
        baby can handle its feedings and resultant gas better. Osteopathic
        treatment can also address connective tissue tension present around the
        abdominal organs, especially in the umbilical area and near where the
        esophagus meets the stomach. In infants who suffer from spitting up,
        vomiting or reflux, the normal clockwise motion of the abdominal fascia
        may be impaired and need corrective treatment.
      </p>

      <p>
        Occasionally the digestive distress of breast-fed babies can be traced
        to foods in the mother’s diet. When these offending foods are removed
        from her diet, the improvements in the baby can be dramatic. In the same
        way, babies who are bottle-fed may find relief in switching to a
        different formula.
      </p>

      <h2>Healthy Choices</h2>

      <p>
        Opinions vary on the topic of introduction of solid foods into a baby’s
        diet. Most babies are not ready before six months and demonstrate their
        readiness by the presence of teeth and a keen interest in their parent’s
        eating. Many physicians agree that wheat, dairy, eggs, citrus and honey
        should be avoided until after 12 months of age and introduced cautiously
        thereafter. Introducing only one new food at a time allows one to watch
        for allergic responses, often seen in the form of digestive upset or
        skin rashes, especially around the mouth and anus.
      </p>

      <p>
        It can take up to five days of eating a new food before a negative
        reaction is seen. A food which results in an allergic type response
        should be removed from the diet and not tried again for at least several
        months. Because continued exposure to an allergic food fosters a more
        severe level of allergy, exercising this level of care when solid foods
        are introduced reaps benefits in a wider choice of foods later in life.
      </p>

      <p>
        “You are what you eat” is a caution that is perhaps more relevant now
        than ever before. Depletion of topsoil has resulted in vegetables,
        fruits and grains lacking essential nutrients. The economic demands on
        farmers have resulted in the widespread use of pesticides, artificial
        ripening agents and fertilizers containing waste products which should
        not be recycled into our soils.
      </p>

      <p>
        Dairy products and meat are contaminated by animal feed containing
        antibiotics, hormones and animal by-products. Organically grown and
        naturally processed food is free of potentially health damaging
        additives. Making healthy dietary choices during infancy and childhood,
        when all parts of the body are developing, is a crucial step in
        fostering healthy growth of every vital organ, bone, muscle and brain
        cell of the body.
      </p>

      <p>
        A wide spectrum of health care practitioners agree that infancy is not a
        time to receive a diet high in sugar, salt and fat content found in most
        processed foods. Offering ourselves and our children healthy diets is a
        big challenge but one worth taking.
      </p>

      <h2>Childhood Complaints</h2>

      <p>
        Vague, non-specific digestive complaints are commonly seen in childhood.
        Tummy aches and nausea are the cause of days home from school for many
        children and rarely does a standard medical work-up determine the cause.
      </p>

      <p>
        Osteopathic evaluation often reveals that the fascia (connective tissue
        layer) which covers the abdominal organs is pulled in a counterclockwise
        direction. For healthy digestion this motion should move clockwise,
        compatible with the peristaltic motion of the intestines as it moves
        food from mouth to rectum. When the facial motion has reversed,
        complaints such as constipation, nausea and stomach aches are common.
        Osteopathic treatment assists the body in correcting the motion of this
        fascia and restoring normal function.
      </p>

      <p>
        Both the vagus nerve and nerves originating in the lower portions of the
        spine are essential to a healthy digestive system. Children who have
        suffered injury, especially to the lower back or sacrum (at the base of
        the spine), may be experiencing digestive problems as a result of this
        trauma. Injury to the pelvis, either traumatic or surgical, can result
        in poor function of the sling of muscles at the lowest part of the
        pelvis, called the pelvic diaphragm. This sling of muscles operates like
        the thoracic diaphragm and, when functioning normally, moves up and down
        with respiration. This diaphragm-like motion is essential to the health
        of the digestive system, and it is vital to restore it in children
        suffering from constipation, recovering from pelvic injury or after
        surgery in this area. A hard fall to the lower back, sacrum or groin can
        be enough to impact gastrointestinal health.
      </p>

      <h2>Urinary Problems</h2>

      <p>
        Restoration of motion in the pelvic diaphragm is also an essential part
        of the osteopathic management of problems such as bladder infections and
        menstrual cramps. The problem of nighttime bed wetting is a complex one
        which may or may not respond to osteopathic manipulative treatment. In
        some children, treatment can help to normalize the neural control
        relevant to bladder emptying and may be very helpful in this clinical
        problem.
      </p>

      <p>
        Some children are genetically predisposed to the problem and don’t “grow
        out of it” until the age at which the problem resolved for their
        affected parent.
      </p>

      <p>
        The less common problem of bladder reflux may respond to osteopathic
        treatment of the facial strains which are present where the urethra
        meets the bladder.
      </p>
    </Article>
  );
};

export default ArticlePediatricDigestiveProblems;
