import Article from "@/components/Article";

const ArticlePediatricDownSyndrome = () => {
  return (
    <Article
      title="Down Syndrome"
      author="Richard A. Feely, D.O., FAAO, FCA, FAAMA"
    >
      <p>
        One might wonder what the value of osteopathic manipulative treatment
        could be for a genetic syndrome. Osteopathic medicine is based on the
        principle that body structure and function are dynamically interrelated.
        When one improves the anatomic interrelationships of structural elements
        of the body (bones, muscles, membranes, tissues, fluids), one sees
        improvement in the function of the body. This holds true whether the
        causes of the structural abnormalities are genetically based or not. It
        is clearly evident in looking at the face of a typical child with Down
        Syndrome that there is a lot about structure that is less than optimal.
        Let’s look at what improvements in functions might be seen by improving
        the structure.
      </p>

      <p>
        Down Syndrome, or Trisomy 21, occurs in about one in 800 births. It is
        almost always the result of a third copy (trisomy) of some or all of the
        genetic material on chromosome 21. Intellectual developmental disorder
        and low muscle tone are probably the two most common hallmarks of Down
        syndrome. There is also a much higher than normal incidence of heart and
        gastrointestinal tract defects which often require surgical correction.
      </p>

      <p>
        Many external body features are characteristic of the syndrome. These
        include among others, an upward slant to the eyes; skin folds at the
        inner edges of the eyes; a flat, wide bridge of the nose; small, low-set
        ears; a shortened front to back dimension of the skull; a recessed
        midportion of the face and a protruding and often furrowed tongue. Some
        of these features contribute to the health complications seen in Trisomy
        21, and some may plat a role in the common neurodevelopmental problems.
      </p>

      <p>
        Changes in most features are possible through osteopathic manipulative
        treatment, and the improvements made structurally are likely to result
        in better functioning.
      </p>

      <h2>Infections</h2>

      <p>
        It is commonly accepted that most children with Down Syndrome have more
        severe respiratory infections, especially of the ears and sinuses. There
        are two reasons for this. One is the genetics of Down Syndrome causes
        abnormalities in the immune system which make it more difficult to
        resist an illness once exposed and harder to heal from it once ill. The
        second reason lies in the structure of the facial features which makes
        drainage of these areas more difficult.
      </p>

      <p>
        The midportion of the face (the area between the eyes and mouth) is
        small and typically set further back in the child with Down Syndrome.
        This means that the sinus cavities are smaller than normal and sometimes
        absent entirely. The wide, flat bridge of the nose blocks the openings
        through which the sinuses drain. The problem is compounded by the
        low-set position of the ears and the smaller than normal diameter of the
        eustachian tube which drains the middle ear to the back of the throat.
        When fluids fill the ears and sinus–spaces that should be occupied by
        air-infections are likely to occur.
      </p>

      <p>
        Drainage is further compromised by the differential growth of the upper
        and lower jaw bones. The upper (maxilla), being part of the midface, is
        small in comparison to the lower (mandible). This also promotes the
        mouth breathing, protruding tongue and difficulty enunciating language
        often see in trisomic children.
      </p>

      <p>
        Through a very gentle touch, an osteopathic physician trained in the
        cranial concept, can help to normalize the relationships of the bones
        and membranes of the of the facial area. By assisting the midface
        structures to come forward, one can see a cosmetic change in eye shape,
        cheekbones, tongue/mouth relationship and bridge of nose. Usually the
        frequency of upper respiratory infections are reduced as well.
      </p>

      <h2>Growth Concerns</h2>

      <p>
        Almost all children with Down Syndrome show delays in gross motor, fine
        motor developmental and language development. These skills often lag
        four months behind at one year of age and eight to ten months behind at
        two years of age. Language is frequently not gained until the fourth to
        sixth year. Though these delays are assumed to be genetically
        predetermined, let’s look at the role that body structure might play.
      </p>

      <p>
        Osteopathic theory asserts that neural pathways in the brain are
        designed to lay themselves down in precise geometric relationships. When
        the cranium (skull) is distorted in its shape, it is not possible for
        these pathways to develop normally.
      </p>

      <p>
        There are several factors contributing to the distorted cranial shape.
        The sutures, where one bone meets another, are often positioned
        abnormally in Down Syndrome. The membranes that encase the central
        nervous system and lie between the brain and the cranium have a powerful
        effect on the growth of the developing skull. These dural membranes
        usually demonstrate very poor mobility in the trisomic child. The front
        to back dimension of the cranium is typically shortened in Down Syndrome
        and is one more factor dictating distorted geometry for the developing
        neural pathways.
      </p>

      <p>
        Osteopathic treatment can effect significant changes in the shape of the
        cranium through addressing the sutures and the tensions in the dural
        membranes. The distortion of the cranial mold appears to contribute
        significantly to the difficulty in performing coordinated motor tasks
        such as grasping and crawling. Most agree that mastery of these tasks is
        a necessary foundation for later learning. Osteopathic treatment,
        therefore, is an important part of the health plan for a child with Down
        Syndrome.
      </p>
    </Article>
  );
};

export default ArticlePediatricDownSyndrome;
