import Article from "@/components/Article";

const ArticlePediatricOrthopedicProblems = () => {
  return (
    <Article
      title="Orthopedic Problems"
      author="Richard A. Feely, D.O., FAAO, FCA, FAAMA"
    >
      <p>
        The vast majority of orthopedic problems in childhood are seen in the
        lower extremities: the feet, legs, knees and hips. When one considers
        the vast changes that a small body must make as it grows from its
        cramped in utero position through crawling to walking, it is not
        surprising to find problems in the lower extremities.
      </p>

      <p>
        The orthopedic condition routinely evaluated for at birth is “congenital
        hip,” where the head of the femur (upper leg bone) cannot seat itself in
        the too shallow depression present in the ilium (hip bone). Though it
        must be treated with bracing, osteopathic treatment helps to normalize
        the joint functions which were inevitably disturbed by the bracing.
        Osteopathic manipulative treatment, which looks to improve body function
        through addressing body structure, assists in the resolution of many
        common orthopedic conditions of childhood.
      </p>

      <p>
        Tibial torsion, the outward bowing of the lower leg, is caused b the
        cramped folding of the baby’s legs in utero, and often resolves
        spontaneously in the first year of life. However, if the torsion is
        accompanied by a distortion between the knee cap and the tibial bone, or
        between the tibia and the nearby fibula, these should be treated
        osteopathically, preferable before the baby begins to walk. When babies
        first stand, they often place their feet far apart for stability,
        thereby standing on the inside edges of their feet. If the stance
        remains wide beyond the first few months of walking, osteopathic
        treatment is recommended.
      </p>

      <p>
        Falling hard on one’s bottom is another normal component of learning to
        stand but is hard on the relationship between the sacrum (at the base of
        the spine) and the vertabrae of the lower back. This common insult, left
        untreated, is probably one of the underlying causes of low back pain
        suffered by adults.
      </p>

      <h2>Toddlers</h2>

      <p>
        Between 10 and 14 months of age, most children begin to walk. As more
        balance is gained, the distance between the feet should become the same
        as the distance between the hips, and the feet should point straight
        forward when the child stands, walks or runs.
      </p>

      <p>
        If this normalization of postural stance is not gained spontaneously,
        osteopathic evaluation and treatment should be pursued. The causes may
        be found in disturbed relationships of the bones of the pelvis or legs
        or in abnormal tensions of the connective tissues or muscles. Correcting
        these osteopathically early in life will foster healthy structural
        growth throughout childhood and adolescence. Although standard medical
        counsel advises waiting, with an expectation that gait abnormalities
        will resolve themselves, we all have seen school children and adults
        plagued with gait problems and the frequently associated back pain.
      </p>

      <h2>Older Children</h2>

      <p>
        Sports injuries are the cause of the vast majority of structural
        problems in this age group. Though they may not result in “skeletal
        deformity” (the common definition of an orthopedic problem), they are
        worthy of osteopathic consideration.
      </p>

      <p>
        Children are physically active by nature and should be both encouraged
        and enabled to engage in the physical activities that interest them.
        However, they as well as their parents must be prepared to accept the
        periodic injuries that accompany physical activity.
      </p>

      <p>
        Knee injuries are common in basketball due to the necessity of rotating
        one’s body over a foot planted on the court. Running sports, such as
        track and soccer, are ideally done only by children whose hip, knee and
        ankle line up vertically. Poor alignment fosters more frequent and more
        severe injuries. All activities played with balls involve the risk of
        impact from the ball, the most serious location being the head. The
        intentional “headers” of soccer are less damaging to the normal motion
        mechanics of skull joints than are accidental impacts. Football,
        gymnastics, and snow or ice-based sports are fraught with potential
        injury. Osteopathic treatment to release the sprains, strains and bony
        misalignments as they occur is good insurance toward a healthy and
        pain-free adulthood.
      </p>

      <p>
        Some skeletal problems of childhood affecting the hips and/or knees,
        such as slipped epiphysis, Perthes’ disease, Osgood Schlatter disease
        and synovitis, require cessation of sports activities for variable
        periods of time. Though they each have their appropriate orthopedic
        treatment, the recovery of full and pain-free joint function can be
        aided by osteopathic treatment, both during and after the disease
        process.
      </p>

      <h2>Scoliosis</h2>

      <p>
        Scoliostic curves of the spine are most commonly, though not
        exclusively, seen in girls between the ages of 10 and 14. The curves
        vary widely in their severity. The more severe fixed curves require
        bracing or surgical treatment. In scoliosis, the vertebrae are both
        sidebent and rotated. Ribs are displaced, and muscle groups are
        stretched or shortened. There is often a hip height discrepancy.
      </p>

      <p>
        Although discomfort is rare during adolescence, both pain and disability
        are likely to be experienced later in life if left untreated.
        Osteopathic manipulative treatment can be beneficial for both the more
        mild functional curves and for curves requiring more invasive measures.
        Osteopathic treatment can improve both spinal mobility and degree of
        curve.
      </p>
    </Article>
  );
};

export default ArticlePediatricOrthopedicProblems;
