import Article from "@/components/Article";

const ArticlePediatricTreatmentForNewborns = () => {
  return (
    <Article
      title="Treatment for the Newborn"
      author="Richard A. Feely, D.O., FAAO, FCA, FAAMA"
    >
      <p>
        For centuries, in many parts of the world, highly trained birth
        attendants have seen it as part of their job to correct the stresses
        that birth has placed in the body of the newborn. This constitutes an
        acknowledgment that birth is a difficult process and that measures can
        be taken after birth to assist the baby in its recovery.
      </p>

      <p>
        In industrialized nations of Northern Europe and North America, birth
        has been seen as an event that either leaves no negative impact upon the
        baby or one whose complications, whatever they may be, must be accepted
        and endured by both child and family.
      </p>

      <p>
        Since the late 1800s, when osteopathy became a medical discipline in the
        United States, osteopathic physicians have assisted babies in their
        recovery from the birth experience, thereby helping to promote the best
        possible health and development of the child.
      </p>

      <p>
        Osteopathy is a medical discipline focusing on re-establishing and
        maintaining the natural relationships of bones, muscles, membranes,
        tissues and fluids within the body. Osteopathic manipulative treatment
        promotes the body’s ability to function, develop and heal itself by
        addressing problems found in these structural components.
      </p>

      <p>
        Many older children experiencing learning or behavioral difficulties
        have a history of a traumatic birth or early childhood head blows which
        went uncorrected. Children who suffer from recurrent ear or sinus
        infections frequently have a similar medical history. Although it is
        most useful to address the structural problems originating in the birth
        process shortly after birth, much improvement in the child’s condition
        can be seen if treatment is initiated later.
      </p>

      <h2>The Birth Process</h2>

      <p>
        Birth often results in harmful structural changes. The likelihood of
        trouble increases when the labor and delivery is prolonged or augmented
        by pitocin or when forceps or vacuum extractions are necessary. In
        vaginal delivery, the infant skull is asked to make its passage through
        too small a space. In response, the bones of the skull overlap to
        decrease the size of the head, and often do not return to their natural
        positions after delivery. In order to travel through the birth canal,
        the infant’s head must bend markedly backwards. This puts pressure on
        two nerves (vagal and hypoglossal) which can result in the colic and
        sucking disturbances often seen in newborns.
      </p>

      <p>
        Although C-section babies are spared some of the complications of
        vaginal deliveries, they are also robbed of some of the benefits. The
        transit down the birth canal applies a variety of pressures on the
        infant’s head which help to free it from the shape it was molded to in
        utero. The transit through the birth canal also compresses and
        re-expands the chest wall preparing the baby to breathe and to clear
        fluid from the lungs.
      </p>

      <p>
        Once the baby is born, osteopathic physicians hope to hear a fairly
        immediate and powerful birth cry. Fetal life would be fraught with low
        oxygen levels if it were not for the mother’s higher blood hemoglobin
        levels and the baby’s faster heart rate. The transition from life
        outside is a critical time in which the baby loses its maternal support
        and must provide for its own oxygen.
      </p>

      <p>
        A strong birth cry probably serves two crucial functions. It opens the
        alveolar air sacs throughout the lungs, thereby ensuring adequate levels
        of oxygen so essential to brain development. It may also increase the
        internal pressure within the skull helping to re-expand those bones and
        membranes which were compressed in the birth process.
      </p>

      <h2>Seeking Treatment</h2>

      <p>
        The infant will often communicate the presence of a problem by being
        irritable or difficult to calm. In addition, excessive wakefulness at
        night or reluctance to fall asleep, spitting up or vomiting can have
        their origins in structural disturbances. A parent or health care
        professional may notice visual signs of a structural problem such as
        overlapping of joint lines on the infant’s skull which do not level out
        in the first week of life. Visual asymmetries, such as one side of the
        forehead further forward than the other, the two ears positioned
        differently or the neck held to one side, can and should be corrected.
      </p>

      <p>
        As the baby gets a little older, a parent may notice developmental
        delays. Although there are many reasons that children fall behind a
        normal developmental timetable, some can be successfully addressed
        through osteopathic treatment.
      </p>

      <p>
        The brain does rapid and critical development in the first year of life.
        The nerve pathways are designed to lay themselves down in precise
        geometric relationships. Even slight distortions in the structure of the
        skull can impair the development of the nervous system. These can
        manifest in developmental delays early in childhood and potentially more
        serious learning difficulties later.
      </p>

      <p>
        Some children suffer from medical conditions for which conventional
        medical care has little to offer, conditions such as Down Syndrome or
        cerebral palsy. Osteopathic treatment does not alter the underlying
        genetic defect or birth injury factors, but it can be very effective in
        enhancing the child’s functional capabilities as well as improving
        general health and quality of life for the child and family.
      </p>
    </Article>
  );
};

export default ArticlePediatricTreatmentForNewborns;
