import Article from "@/components/Article";

const ArticleTheTraumaOfBirth = () => {
  return (
    <Article title="The Trauma of Birth" author="Viola M Fryman, D.O.">
      <p>
        The newborn skull is designed to provide maximum accommodation to the
        forces of labor and minimum trauma to the developing brain. However,
        injury to the head during birth is more common than many people realize.
      </p>
      <p>
        In a study of 1,250 newborns I conducted a few years ago, it could be
        demonstrated that severe visible trauma was inflicted on the head–either
        before or during labor–in 10 percent of the infants. Membranous
        articular strains, which could be detected by the physician proficient
        in the diagnostic techniques of osteopathy in the cranial field, were
        present in another 78 percent. Thus, nearly nine of every 10 infants in
        the study had been affected. (1)
      </p>
      <p>
        How important are these membranous articular strains to the physician? I
        have found that common problems of the neonatal period–such as
        difficulty in sucking, vomiting, nervous tension, and irregular
        respiration–are frequently overcome just as soon as these strains are
        corrected. Similar strains are encountered in school children who have
        learning and behavior problems.
      </p>
      <p>
        In a study of 100 children between the ages of five and 14 who were
        having learning or behavioral difficulties, it was found that 79 had
        been born after a long or difficult labor and had one or more of the
        common symptoms of the neonatal period. Also, it is my impression that
        many cases of childhood allergy can be traced to musculoskeletal strains
        originating at the time of birth. (2) And vertebral scoliosis occurring
        in childhood and adolescence is, in many instances, the consequence of
        cranial scoliosis originating during birth. (3 ) Thus, recognition and
        treatment of dysfunction of the craniosacral mechanism in the immediate
        postnatal period represent one of the most, if not the most, important
        phases of preventive medicine in the practice of osteopathic medicine.
      </p>
      <p>
        To gain a clearer understanding of the origin and nature of these
        membranous articular strains, it will be helpful to review the anatomic
        features of the newborn skull and to note how they are affected by the
        forces of labor.
      </p>
      <h2>Labor</h2>
      <p>
        As was mentioned above, the newborn skull is designed to provide maximum
        accommodation to the forces of labor, minimum trauma to the infant’s
        brain, and complete restoration to free mobility of all its parts once
        the stress of labor is over.
      </p>
      <p>
        Just before birth, the infant in utero is positioned for delivery by
        presenting the smallest diameter of his head to the largest diameter of
        the mother’s pelvis; this is the position of full fetal flexion. As
        contractions continue, the infant is conducted by the inclination of the
        maternal pelvic floor into the midline for delivery around the pubic
        symphysis by a process of extension of the head.
      </p>
      <p>
        This descent in full flexion, progressing to birth by extension of the
        head, is of profound significance to the initiation of pulmonary
        respiration. The respiratory activity associated with the vigorous vocal
        activity of the newborn serves to expand the cranial mechanism and
        restore the bones and membranes to their anatomic relationships
        (permitting their free physiologic motion). Healthy sequential
        development of the central nervous system within can then continue.
      </p>
      <p>
        These ideal circumstances, however, seldom occur in our modern,
        civilized world. Owing to such factors as poor nutrition of the mother,
        structural inadequacies before and during pregnancy, drug abuse,
        inadequate preparations for labor, and, sometimes, the mechanical or
        artificial acceleration of labor by an impatient obstetrician, only a
        relatively few infants are born without undue skein or cranial trauma.
      </p>
      <p>
        Instead, structural inadequacies of the maternal pelvis may cause the
        fetus to assume a degree of extension (and lateral cervical flexion)
        greater than the ideal; the result will be a presentation of a portion
        of the head greater than the minimum occipitobregmatic diameter. This
        can range from a moderate extension to posterior occiput, to transverse
        arrest, to brow presentation, or even to a complete extension in which
        the face itself presents-a position in which vaginal delivery is
        impossible. In such a circumstance, cesarean section will be necessary
        if the baby is to survive.
      </p>
      <p>
        But the compressive forces will have already traumatized the head as the
        uterine contractions force it progressively towards the birth canal.
        Prominence of the base of an anterior maternal sacrum may obstruct
        descent of the head on one side, and such asynclitism can distort the
        cranial mechanism. The presence of large twins, both striving to present
        the head at the same time, may cause cranial stress to one or both even
        before active labor begins. These are only a few of the mechanical
        insults that may occur before birth.
      </p>
      <p>
        So much for the passage of the infant into the birth canal. Now let us
        consider the structure of the infant skull itself at the time of birth.
      </p>
      <h2>Anatomy</h2>
      <p>
        The vault of the newborn skull is a membranous structure. Plates of bone
        are enveloped in two layers of membrane, which are in apposition at the
        anterior and posterior fontanelles and sometimes at the pterion and
        asterion. These plates of membranous bone are designed to telescope into
        each other as the skull passes through the birth canal-the parietals
        overriding the frontal at the coronal suture, and the occiput at the
        lambdoid suture. The degree of this overriding is controlled and limited
        by the investing aural membranes.
      </p>
      <p>
        The bones of the base develop from the cartilaginous chondrocranium. At
        birth, development is still incomplete.(4) The occipital bone is in four
        parts, united by intraosseous articular cartilage. The spheroid is in
        three parts, the temporal in two, the maxilla in two, the frontal
        frequently in two.
      </p>
      <p>
        The cranial suture is designed for a very small but vital degree of
        motion.(5) How much greater is the potential motion of the bones of the
        developing newborn skull! At this time each part of each of these bones
        functions virtually as a separate bone, moving in relation to its other
        parts.
      </p>
      <p>
        Let us consider the occiput. It is most commonly the presenting part,
        and therefore the part that may take the brunt of the trauma of labor.
        The four developmental parts surround the foremen magnum. The base
        articulates anteriorly with the base of the spheroid. Posterolaterally,
        it articulates with the lateral masses. The hypoglossal nerve, which
        innervates the muscles of the tongue, passes out of the skull between
        the base and the lateral mass, through the intraosseous cartilage in the
        space that will become the condylar canal. The occipital condyle, which
        articulates with the atlas, spans the intraosseous cartilage; its
        anteromedial third is found on the base, the posterolateral two-thirds
        on the lateral mass.
      </p>
      <p>
        Immediately anterolateral to this condylar area is the jugular foremen,
        a space between the condylar part of the occiput and the petrous portion
        of the temporal. This foremen gives passage not only to the jugular vein
        but also to cranial nerves IX, X, and XI (glossopharyngeus, vague, and
        accessorius, respectively). The vagus nerve provides innervation to the
        gastrointestinal and cardiorespiratory systems.
      </p>
      <p>
        The supraocciput formed in cartilage fuses with the membranous
        interparietal bone to form the occipital squama. Compression transmitted
        through the squama to the condylar part on one side may disturb the
        function of the vagus and/or hypoglossal nerve, causing vomiting,
        irregular respiration, and difficulty in sucking. If this compression is
        transmitted further to the base, the relationship of the base of the
        occiput to the base of the spheroid may be distorted, causing a lateral
        strain of the sphenobasilar articulation and a parallelogram deformity
        of the cranium(5) (Figure 1).
      </p>
      <p>
        Figure 1. Lateral strain of the sphenobasilar articulation. Viewed from
        above, the sphenobasilar symphysis has been strained (displaced), with
        the basisphenoid moving to one side and the basiocciput to the other.
        Both bones side-bend about parallel vertical axes in the same direction.
        The lesion is named from the position of the basisphenoid: lateral
        strain with the spheroid to the right, etc. (From Magoun, H.{" "}
        <em>Osteopathy in the Cranial Field.)</em>
      </p>
      <p>
        Bilateral condylar compression may cause a buckling type of strain of
        the cranial base, producing a vertical strain between the occiput and
        the spheroid at the sphenobasilar articulation. This may be associated
        not only with vagal dysfunction but also with symptoms of tension,
        spasticity, opisthotonic spasms, sleeplessness, and excessive crying due
        to the irritation of the pyramidal tracts on the anterior and lateral
        aspects of the brain stem in the foremen magnum. This should be
        considered as a precursor of the spastic type of cerebral palsy.
      </p>
      <p>
        The spheroid bone is in three parts at birth; the central body bears the
        lesser wings, with the greater wings (from which the pterygoid process
        subtends) on either side. The greater wing-pterygoid unit articulates
        with the body by an intraosseous cartilage. This is situated immediately
        beneath the cavernous sinus, through which pass cranial nerves III, IV,
        and VI, innervating the extraocular muscles, and the ophthalmic division
        of V, which is sensory to the orbit, upper face and scalp. The body of
        the spheroid articulates with the base of the occiput posteriorly and is
        therefore distorted by the lateral or vertical strains resulting from
        condylar compression. Anteriorly the body carries the lesser wings,
        which enter into the formation of the orbit. The orbit is approximately
        pyramidal in shape; the apex is at the optic foremen-that is, the root
        of the lesser wing at the body. Its anatomic integrity is dependent on
        the relationship of the greater wing to the lesser wing, which is in
        fact the relationship of the greater wingpterygoid unit to the body.
      </p>
      <p>
        In the event of a lateral strain at the base due to unilateral condylar
        compression of the occiput, the orbit will be distorted by rotation of
        the base of the spheroid carrying the lesser wing anterior on one side
        and posterior on the other. In the parallelogram head due to lateral
        compression, the greater wing is compressed medially and carried forward
        on one side and posterior on the other. In either event, lateral muscle
        imbalance of the eyes is commonly found in varying degrees ranging from
        mild esophoria or exophoria to severe strabismus.
      </p>
      <p>
        The temporal bone is in two parts at the time of birth -the petromastoid
        portion, developed in cartilage that projects obliquely between the
        occiput and the greater wing of the spheroid to articulate at its apex
        with the body of the spheroid, and the squamous portion, developed in
        membrane the forms the greater part of the lower lateral wall of the
        skull. The tympanic portion is not yet a bony canal but resembles a
        horseshoe adherent to the inferior posterior aspect of the squama. These
        two parts, the squamous and tympanic, unite just before birth. The
        petromastoid portion contains the auditory and the vestibular apparatus.
      </p>
      <p>
        The auditory apparatus consists of the bony eustachian tube emerging
        between the petrous and squamous portions, from which the cartilaginous
        tube extends to the fossa of Rosenmuller. The eustachian tube is
        susceptible to distortion, which may impair hearing if lateral stress
        compresses the squamous portion. Laterally the eustachian tube opens
        into the middle ear, which, by the ossicular mechanism, transmits the
        auditory vibrations received from the tympanic membrane to the internal
        ear. The vestibular apparatus includes the semicircular canals,
        precisely related to each other and geometrically balanced with those of
        the opposite side. Distortion of the axis of the petrous portion may
        disturb this delicate mechanism of equilibrium.
      </p>
      <p>
        The maxilla develops in two parts-the premaxilla, which will give origin
        to the incisor teeth, and the body, which carries the canine and all the
        other upper teeth. Angulation between these two developmental parts of
        the maxilla gives rise to malalignment and malocclusion in later years.
      </p>
      <p>
        Thus far our consideration has been directed to certain structural
        changes that may sometimes be visible and are always palpable following
        various difficulties of labor. Radiologic techniques have been developed
        to substantiate many of these palpatory observations and confirm their
        persistence in childhood problems.(7)
      </p>
      <h2>Examination</h2>
      <p>
        The craniosacral mechanism of the newborn infant should be examined
        within the first few days of life. There is probably no field of
        osteopathic diagnosis where the injuction “if at first you don’t
        succeed, try, try again” applies more than in the examination of the
        newborn cranium. The mobility of the cranial mechanism is much greater
        at this age than it is in the adult skull, although the range of motion
        is of course much smaller. Dr. R. McFarlane Tilley used to speak of the
        amplification mechanism within the human hand and brain, which permits
        the perception of motion in the range of 0.0001 inch. It is this
        perceptive mechanism that must be developed in order to make a
        meaningful examination and to complete an adequate treatment program for
        these infants.
      </p>
      <p>
        Furthermore, one must learn to palpate motion within motion, for these
        infants rarely lie absolutely still for an examination. One should first
        consider the contours and articulations by passing the hands gently over
        the surface. Look for asymmetry, bossing of the frontals or parietals,
        grooves above the eyebrows, overlapping of one bone on the other at the
        coronal or lambdoid suture, prominence and compression of the sagittal
        or metopic suture, and depression of the pterion. Let the occiput rest
        in the palm of the hand, and note unusual prominence of the
        interparietal occiput or hard flattening of the supraocciput. Study the
        relative size and position of the eyes and nostrils and the inclination
        of the mouth. Examination for inherent motility will be facilitated if
        the baby is nursing or sleeping. Here is a check list that may be
        helpful:
      </p>
      <p>
        1. Place the hands gently on the vault, with the index fingers on the
        greater wing of the spheroid and the little fingers on the lateral
        angles of the occiput. The other fingers lie comfortably between them.
        Is your first palpatory impression that your two hands are symmetrical?
      </p>
      <p>
        2. Are the index finger and the little finger of one hand cephalad or
        superior to those of the other, as in a torsion strain. If so, the
        spheroid and occiput will have rotated around an anteroposterior axis in
        opposite directions, elevating the greater wing of the spheroid on one
        side and the lateral angle of the occiput on the other (Figure 2).
      </p>
      <p>
        Figure 2. Torsion strain. Torsion of the sphenobasilar symphysis occurs
        about an axis running from the nasion (anterosuperior) to opisthion
        (posteroinferior) at approximately right angles to the plane of the
        sphenobasilar symphysis. In bottom view, a left torsion lesion is
        diagrammed, with the greater wing and basisphenoid high on the left side
        and the basiocciput and squama lower on that same side. (From Magoun, H.{" "}
        <em>Osteopathy in the Cranial Field, </em>Second Edition. Kirksville,
        Mo.: Journal Printing Company, 1966).
      </p>
      <p>
        3. Are the index finger and little finger of one hand caudad or inferior
        to those of the other hand, with a sense of fullness in the palm of the
        inferior hand, as in a side-bending rotation strain. In this instance,
        the spheroid and occiput have side-bent in opposite directions around
        parallel vertical axes and rotated inferiorly into the convexity thus
        created.
      </p>
      <p>
        4. Is there a sensation that the index fingers on the greater wings are
        directed towards one side, while the little fingers on the occiput are
        carried to the other side? This is lateral strain (Figure 1). Owing to a
        lateral force, the spheroid and the occiput have rotated in the same
        direction around parallel vertical axes, causing a shearing strain at
        the symphysis between them.
      </p>
      <p>
        5. Are the two index fingers on the greater wings forward and downward
        (caudad) as compared with the little fingers on the lateral angles?
        Conversely, the index fingers may be superior (cephalad). These are
        vertical strains (Figure 3 ). Both superior and inferior strains are
        shown in the diagrams (superior on the left). The spheroid and the
        occiput have rotated in the same direction around parallel transverse
        axes, producing a vertical shearing strain at the sphenobasilar
        articulation.
      </p>
      <p>
        Figure 3. Vertical strains of the sphenobasilar symphysis. Viewed from
        the side, the sphenobasilar symphysis has been strained or displaced
        before ossification, with the basisphenoid moving cephalad (flexion) and
        the basiocciput moving caudad (extension), or vice versa. Both bones
        rotate about parallel transverse axes in the same direction. (From
        Magoun, H. <em>Osteopathy in the Cranial Field </em>Second Edition.
        Kirksville, Mo.: Journal Printing Company, 1966.
      </p>
      <p>
        6. Is there a sense of hardness and tension under your hands, resembling
        wood? This suggests a compression strain.
      </p>
      <p>
        These palpatory observations of asymmetry are clues to the dysfunction
        of this mechanism: But it is the nature of the inherent cranial rhythmic
        impulse-its symmetry, rate, amplitude, and constancy of pattern- that is
        important. If the inherent motion is distorted, impeded, limited, or
        retarded, there are certainly membranous strains that need attention.
      </p>
      <p>
        It is not possible to develop the necessary tactile skills in a few days
        or during a brief course of instruction. But with assiduous application,
        the sensitivity will be developed, and you will be able to make these
        vital diagnoses at the age when they are most susceptible to correction.
      </p>
      <p>
        7. With your index finger on the greater wing of the spheroid and your
        little finger on the lateral angle of the occiput, be still and permit
        the mechanism to convey its movement through your fingers and hands. Is
        there rhythmic, symmetric expansion and contraction of{" "}
        <strong>external and internal rotation </strong>of the bilateral vault
        bones that accommodates the <strong>flexion and extension </strong>of
        the spheroid and occiput? (This is transmitted to the index fingers as a
        rhythmic downward and forward and then upward and backward cyclic
        motion, while the little fingers also move downward and backward, then
        upward and forward. ) Is the direction of motion that of the torsion,
        side-bending rotation, vertical or lateral strains?
      </p>
      <p>
        8. Cradle the occiput in the hands, and place the tip of the index
        fingers on the mastoid process of the temporal bone bilaterally. (While
        there is no bony mastoid process at birth, the attachment of the
        sternomastoid muscle provides the palpatory landmark.) Is the sensation
        that of symmetry, or does one fingertip seem posteromedial to the other?
        If the tip of the mastoid is posteromedial (i.e., less prominent) the
        temporal bone is externally rotated. If it is anterolateral (more
        prominent), the temporal bone is internally rotated. This asymmetry of
        the mastoid process is indicative of the position of the occiput, with
        the internally rotated temporal bone or the prominent mastoid process
        being associated with the elevated lateral angle of the occiput. Is one
        temporal bone more anterior than the other without the medial or lateral
        motion? This suggests a lateral strain of the sphenobasilar articulation
        that has carried the head into a parallelogram distortion. Again, be
        still, and observe the relative mobility of the two temporal bones.
      </p>
      <p>
        9. Steadying the head with the two fingers gently on the frontal bone,
        slip the other hand down and around the curve of the prominence of the
        occiput. Two fingers are usually adequate. Note the tension of the
        suboccipital muscles, and compare the two sides of the midline. Does one
        of the two palpating fingers come in contact with the arch of the atlas
        before the other? If it does, this is probably the side of condylar
        compression, for the occiput will have rotated anteriorly on this side.
        Be still, and observe the motility. Impaired motion on one side or both
        will suggest, respectively, unilateral or bilateral condylar
        compression.
      </p>
      <p>
        10. By now the baby may have finished nursing and may even be asleep.
        Now change your position, and sit at the infant’s right side, at the
        level of his lower limbs. Steady the pelvis with the left hand while
        placing two fingers of the right hand under the sacrum. Are the two
        sides of the body symmetrical? Does the sacrum project into the hand at
        the coccyx? Be still; observe the motion of the sacrum in relation to
        the ilia. Is the motion symmetrical, around a transverse axis? Or do you
        find a rotating motion superiorly on one side, around an anteroposterior
        axis?
      </p>
      <p>
        11. Place the hands under the lumbar spine, and note the presence of
        lateral flexion producing a concavity to one side. Relate this to
        lateral motion of the pelvis.
      </p>
      <p>
        The treatment of the craniosacral mechanism cannot be learned solely
        from the written word. The palpatory skills must be developed and
        evaluated with supervised experience. But the treatment, in summary,
        consists of finding the point of balanced membranous tension of the
        mechanism, holding it, and permitting the inherent therapeutic force
        within to normalize the body.
      </p>
      <p>
        “The osteopath reasons that order and health are inseparable,” said Dr.
        Andrew Taylor Still, “and that when order in all parts is found, disease
        cannot prevail.” And as Dr. W. G. Sutherland reminded his students, as
        the twig is bent, so the tree is inclined.
      </p>
      <p>
        Give attention to those little bent twigs, so that they may grow into
        handsome, healthy, happy generations for the future.
      </p>
      <h2>References</h2>
      <p>
        1. Frymann, V. M. Relation of disturbances of craniosacral mechanism to
        symptomatology of the newborn: Study of 1,250 infants.{" "}
        <em>J.A.O.A. 65 </em>(1966), 1059-1075.
      </p>
      <p>
        2. Frymann, V. M. The osteopathic approach to the allergic patient.{" "}
        <em>D.O. 10:7 </em>(1970), 159-164.
      </p>
      <p>
        3. Cathie, A. Growth and nutrition of the body with special reference to
        the head. <em>Yearbook of the Academy of Applied Osteopathy, </em>
        1962,pp.149-153.
      </p>
      <p>
        4. Crelin, E. S. <em>Anatomy of the Newborn: An Atlas. </em>
        Philadelphia: Lea &amp; Febiger, 1969.
      </p>
      <p>
        5. Pritchard, J. J., Scott, J. H., and Girgis, F. G. The structure and
        development of cranial and facial sutures. <em>J. Anat. 90 </em>
        (1956), 73-86.
      </p>
      <p>
        6. Magoun, H. I. <em>Osteopathy in the Cranial Field, </em>Second
        Edition. Kirksville, Mo.: Journal Printing Company, 1966, p. 133.
      </p>
      <p>
        7. Greenman, P. E. Roentgen findings in the craniosacral mechanism.{" "}
        <em>J.A. O.A. 70 </em>(1970), 60-71.
      </p>
      <p>
        8. Still., A. T. <em>Philosophy of Osteopathy. </em>Ann Arbor, Mich.:
        Edwards Brothers 1899
      </p>
    </Article>
  );
};

export default ArticleTheTraumaOfBirth;
