import Article from "@/components/Article";

const ArticleWhatIsADo = () => {
  return (
    <Article
      title="What is D.O.?"
      author="Richard A. Feely, D.O., FAAO, FCA, FAAMA"
    >
      <p>
        If you’re like most people, you’ve been going to a doctor ever since you
        were born, and perhaps were not aware whether you were seeing a D.O.
        (osteopathic physician) or an M.D. (allopathic physician). You may not
        even be aware that there are two types of complete physicians in the
        United States.
      </p>
      <p>
        The fact is, that both D.O.s and M.D.s are fully qualified physicians
        licensed to perform surgery and prescribe medication in all 50 states.
        Is there any difference between these two kinds of doctors? Yes. And no.
      </p>
      <h2>DOs and MDs</h2>
      <ol>
        <li>
          Applicants to both D.O. and M.D. colleges typically have a four-year
          undergraduate degree with an emphasis on scientific courses.
        </li>
        <li>
          Both D.O.s and M.D.s complete four years of basic medical education.
        </li>
        <li>
          After medical school, both D.O.s and M.D.s can choose to practice in a
          specialty area of medicine–such as psychiatry, surgery or
          obstetrics–after completing a residency program which requires an
          additional two to six years of training.
        </li>
        <li>
          Both D.O.s and M.D.s must pass comparable state licensing
          examinations.
        </li>
        <li>
          D.O.s and M.D.s both practice in fully accredited and licensed health
          care facilities.
        </li>
        <li>
          D.O.s comprise a separate, yet equal branch of American medical care.
          Together, D.O.s and M.D.s enhance the state of care available in
          America.
        </li>
      </ol>
      <h2>Something Extra</h2>
      <ul>
        <li>
          Osteopathic medical schools emphasize training students to be primary
          care physicians.
        </li>
        <li>Osteopathic physicians focus on preventive health care.</li>
        <li>
          D.O.s receive extra training in the musculoskeletal system — your
          body’s interconnected system of nerves, muscles and bones that make up
          two-thirds of its body mass. This training provides osteopathic
          physicians with a better understanding of the ways that an injury or
          illness in one part of your body can affect another.
        </li>
      </ul>
      <p>
        Osteopathic manipulative treatment (OMT) is incorporated in the training
        and practice of osteopathic physicians. With OMT, osteopathic physicians
        use their hands to diagnose injury and illness and to encourage your
        body’s natural tendency toward good health. By combining all other
        medical procedures with OMT, D.O.s offer their patients the most
        comprehensive care available in medicine today.
      </p>
      <h2>More than a Century of Care</h2>
      <p>
        Osteopathic medicine is a unique form of American medical care that was
        developed in 1874 by Dr. Andrew Taylor Still. Dr. Still was dissatisfied
        with the effectiveness of 19th Century medicine. He believed that many
        of the medications of his day were useless or even harmful. Dr. Still
        was one of the first in his time to study the attributes of good health
        so that he could better understand the process of disease.
      </p>
      <p>
        In response, Dr. Still founded a philosophy of medicine based on ideas
        that date back to Hippocrates, the father of medicine. The philosophy
        focuses on the unity of all body parts. He identified the
        musculoskeletal system as a key element of health. He recognized the
        body’s ability to heal itself and stressed preventive medicine, eating
        properly and keeping fit.
      </p>
      <p>
        Dr. Still pioneered the concept of “wellness” more than 125 years ago.
        In today’s terms, personal health risks–such as smoking, high blood
        pressure, excessive cholesterol levels, stress and other lifestyle
        factors–are evaluated for each individual. In coordination with
        appropriate medical treatment, the osteopathic physician acts as a
        teacher to help patients take more responsibility for their own
        well-being and change unhealthy patterns.
      </p>
      <p>
        For more about the history of the profession, visit The History of
        Osteopathic Medicine Virtual Museum.
      </p>
      <p>
        Just as Dr. Still pioneered osteopathic medicine on the Missouri
        frontier in 1874, today osteopathic physicians serve as modern day
        medical pioneers.
      </p>
      <ul>
        <li>
          Over half of all osteopathic physicians practice in primary care areas
          such as pediatrics, family practice, obstetrics/gynecology and
          internal medicine.
        </li>
        <li>
          Many D.O.s fill a critical need for doctors by practicing in rural and
          medically underserved areas.
        </li>
      </ul>
      <p>
        Today osteopathic physicians continue to be on the cutting edge of
        modern medicine. D.O.s are able to combine today’s medical technology
        with their ears, to listen compassionately to their patients; their
        eyes, to see their patients as whole persons; and their hands, to
        diagnose and treat injury as well as illness.
      </p>
      <p>
        “As an osteopathic physician, I believe in prevention. I am committed to
        educating my patients so they can take the necessary steps to live and
        maintain healthier lifestyles.”
      </p>
      <p>Tyler C. Cymet, D.O., Internal medicine, Baltimore</p>
    </Article>
  );
};

export default ArticleWhatIsADo;
