import Article from "@/components/Article";
import Link from "next/link";

const ArticleYamamotoNewScalpAcupunctureFaq = () => {
  return (
    <Article
      title="Yamamoto New Scalp Acupunture FAQ"
      author="Richard A. Feely, D.O., FAAO, FCA, FAAMA"
    >
      <p>
        <strong>Q. What training is required for YNSA?</strong>
      </p>
      <p>
        A. YNSA’s founder, Dr. Toshikatsu Yamamoto of Miyazaki, Japan, teaches a
        one-week course to MDs and osteopaths in Japan, and conducts YNSA
        seminars in the United States. A physician needs to have been trained in
        acupuncture before studying YNSA.
      </p>
      <p>
        Dr. Yamamoto has also lectured to licensed acupuncturists at the New
        England School of Acupuncture.
      </p>

      <p>
        <strong>Q. How effective is YNSA?</strong>
      </p>
      <p>
        A. YNSA is very effective in treating pain conditions, and can be used
        to modify most other medical conditions that are treatable by
        acupuncture.
      </p>

      <p>
        <strong>Q. How is YNSA different from traditional acupuncture?</strong>
      </p>
      <p>
        A. YNSA is a microsystem of acupuncture located in the head and scalp,
        containing the 12 main acupuncture meridians. The 12 main acupuncture
        meridians are represented by ypsilon points located on the side of the
        head. This microsystem is further divided into 40 basic anatomical
        points on the forehead and 40 points on the back of the skull that
        relate to all the body parts—head, shoulders, arms, spine, etc. By
        treating these acupoints on the head, the physician can relieve pain or
        dysfunction in the corresponding part of the body.
      </p>

      <p>
        <strong>Q. How are the acupoints in YNSA organized?</strong>
      </p>
      <p>
        A. YNSA is divided into the left and right side of the head. The left
        side of the head is further divided into the yin side, or front of the
        head;
      </p>
      <p>
        and the yang side, which is the posterior, or back of the head. The
        dividing line between the front and back of the head comes where the top
        of the ear attaches to the skull. The yin side and the yang side are
        each further divided into an upper and lower half. This yields 12
        acupoints representing the 12 meridians on the lower half of the yin, or
        left side of the head, and 12 acupoints on the upper half of the yin
        side of the head. Thus there are 24 points in front of the ear in the
        yin area; the same is true for the yang, or right side.
      </p>
      <p>
        <strong>Q. How painful is YNSA</strong>
      </p>
      <p>
        A. YNSA is less painful than drawing blood. However, there is some pain
        involved because there is not a lot of fat where YNSA needles are
        inserted. The head has a lot of nerve endings and is thus a sensitive
        area.
      </p>

      <p>
        <strong>Q. How often is YNSA administered?</strong>
      </p>
      <p>
        A. In Japan, YNSA is often administered daily, or two to three times a
        week. In the US, it is normally administered once or twice weekly on an
        outpatient basis.
      </p>
      <p>
        <strong>Q. How fast does YNSA produce pain relief?</strong>
      </p>
      <p>
        A. Relief can occur within five to 10 seconds of placing the needle at
        the correct acupuncture point.
      </p>

      <p>
        <strong>Q. How long-lasting is the pain relief?</strong>
      </p>
      <p>
        A. Relief can initially last from a few hours to a couple of days. Most
        commonly, the pain returns after a few hours. The pain relief lasts
        longer and longer with each successive treatment.
      </p>

      <p>
        <strong>Q. Is there a needle-less form of YNSA?</strong>
      </p>
      <p>
        A. Yes, there have been lasers used to treat these acupuncture points in
        Japan. However, these laser treatments are not approved for use in the
        US.
      </p>

      <p>
        <strong>
          Q. How many trained YNSA practitioners are there in the US?
        </strong>
      </p>
      <p>
        A. There are currently only about 60 physicians in the US who have been
        personally trained by Dr. Yamamoto. Dr. Feely was the first American
        osteopath to travel to Japan for YNSA training in 1993; he returned to
        Japan for further training in 1997.
      </p>
      <p>
        <strong>Q. Is there a clearinghouse for physicians using YNSA?</strong>
      </p>
      <p>
        A. There is no YNSA clearinghouse yet. The best clearinghouse for
        physician acupuncture is the American Academy of Medical Acupuncture:{" "}
        <Link
          href="http://www.medicalacupuncture.org/findadoc/index.html"
          target="_blank"
        >
          www.medicalacupuncture.org/findadoc/index.html
        </Link>
      </p>
      <p>
        <strong>Q. Is YNSA covered by insurance?</strong>
      </p>
      <p>
        A. Most medical insurance does not pay for acupuncture; check your
        policy to verify the benefits under your plan.
      </p>
      <p>
        <em>Page modified on 5/15/2011</em>
      </p>
    </Article>
  );
};

export default ArticleYamamotoNewScalpAcupunctureFaq;
